@@ -17,10 +17,10 @@ import enum
 import json
 import os
 import re
+import urllib
 
 from oslo_config import cfg
 from oslo_log import log as logging
-from six.moves import urllib
 import webob
 
 from cinder.api import api_utils
@@ -354,9 +354,17 @@ def get_cluster_host(req, params, cluster_version=None):
 
 def _initialize_filters():
     global _FILTERS_COLLECTION
-    if not _FILTERS_COLLECTION:
-        with open(CONF.resource_query_filters_file, 'r') as filters_file:
-            _FILTERS_COLLECTION = json.load(filters_file)
+    if _FILTERS_COLLECTION:
+        return
+
+    if not os.path.exists(CONF.resource_query_filters_file):
+        LOG.error(
+            "resource query filters file does not exist: %s",
+            CONF.resource_query_filters_file)
+        return
+
+    with open(CONF.resource_query_filters_file, 'r') as filters_file:
+        _FILTERS_COLLECTION = json.load(filters_file)
 
 
 def get_enabled_resource_filters(resource=None):
@@ -438,7 +446,11 @@ def reject_invalid_filters(context, filters, resource,
                 invalid_filters.append(key)
     if invalid_filters:
         if 'all_tenants' in invalid_filters:
+            # NOTE: this is a special case: the cinderclient always adds
+            # 'all_tenants', so we don't want to hold that against a non-admin
+            # user and we silently ignore it.  See Bug #1917574.
             invalid_filters.remove('all_tenants')
+            filters.pop('all_tenants')
         if len(invalid_filters) == 0:
             return
         raise webob.exc.HTTPBadRequest(
