@@ -16,12 +16,13 @@
 #    under the License.
 
 """The backups api."""
+from http import HTTPStatus
 
 from oslo_log import log as logging
 from oslo_utils import strutils
-from six.moves import http_client
 from webob import exc
 
+from cinder.api import api_utils
 from cinder.api import common
 from cinder.api import extensions
 from cinder.api import microversions as mv
@@ -58,7 +59,7 @@ class BackupsController(wsgi.Controller):
 
         return self._view_builder.detail(req, backup)
 
-    @wsgi.response(http_client.ACCEPTED)
+    @wsgi.response(HTTPStatus.ACCEPTED)
     def delete(self, req, id):
         """Delete a backup."""
         context = req.environ['cinder.context']
@@ -88,9 +89,10 @@ class BackupsController(wsgi.Controller):
     @common.process_general_filtering('backup')
     def _process_backup_filtering(self, context=None, filters=None,
                                   req_version=None):
-        utils.remove_invalid_filter_options(context,
-                                            filters,
-                                            self._get_backup_filter_options())
+        api_utils.remove_invalid_filter_options(
+            context,
+            filters,
+            self._get_backup_filter_options())
 
     def _convert_sort_name(self, req_version, sort_keys):
         """Convert sort key "name" to "display_name". """
@@ -142,7 +144,7 @@ class BackupsController(wsgi.Controller):
     # - whether requested volume_id exists so we can return some errors
     #   immediately
     # - maybe also do validation of swift container name
-    @wsgi.response(http_client.ACCEPTED)
+    @wsgi.response(HTTPStatus.ACCEPTED)
     @validation.schema(backup.create, mv.V2_BASE_VERSION,
                        mv.get_prior_version(mv.BACKUP_METADATA))
     @validation.schema(backup.create_backup_v343, mv.BACKUP_METADATA,
@@ -199,7 +201,7 @@ class BackupsController(wsgi.Controller):
         retval = self._view_builder.summary(req, dict(new_backup))
         return retval
 
-    @wsgi.response(http_client.ACCEPTED)
+    @wsgi.response(HTTPStatus.ACCEPTED)
     @validation.schema(backup.restore)
     def restore(self, req, id, body):
         """Restore an existing backup to a volume."""
@@ -250,7 +252,7 @@ class BackupsController(wsgi.Controller):
         LOG.debug('Exported record output: %s.', retval)
         return retval
 
-    @wsgi.response(http_client.CREATED)
+    @wsgi.response(HTTPStatus.CREATED)
     @validation.schema(backup.import_record)
     def import_record(self, req, body):
         """Import a backup."""
