@@ -12,9 +12,8 @@
 #    under the License.
 
 """The volume type access extension."""
+from http import HTTPStatus
 
-import six
-from six.moves import http_client
 import webob
 
 from cinder.api import extensions
@@ -106,8 +105,8 @@ class VolumeTypeActionController(wsgi.Controller):
             volume_types.add_volume_type_access(context, id, project)
         # Not found exception will be handled at the wsgi level
         except exception.VolumeTypeAccessExists as err:
-            raise webob.exc.HTTPConflict(explanation=six.text_type(err))
-        return webob.Response(status_int=http_client.ACCEPTED)
+            raise webob.exc.HTTPConflict(explanation=str(err))
+        return webob.Response(status_int=HTTPStatus.ACCEPTED)
 
     @wsgi.action('removeProjectAccess')
     @validation.schema(volume_type_access.remove_project_access)
@@ -118,7 +117,7 @@ class VolumeTypeActionController(wsgi.Controller):
 
         # Not found exception will be handled at the wsgi level
         volume_types.remove_volume_type_access(context, id, project)
-        return webob.Response(status_int=http_client.ACCEPTED)
+        return webob.Response(status_int=HTTPStatus.ACCEPTED)
 
 
 class Volume_type_access(extensions.ExtensionDescriptor):
