@@ -55,7 +55,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import units
-from six.moves import range
 
 from cinder.backup import driver
 from cinder import exception
@@ -244,6 +243,11 @@ class CephBackupDriver(driver.BackupDriver):
         """Determine if journaling is supported by our version of librbd."""
         return hasattr(self.rbd, 'RBD_FEATURE_JOURNALING')
 
+    @property
+    def _supports_fast_diff(self):
+        """Determine if fast-diff is supported by our version of librbd."""
+        return hasattr(self.rbd, 'RBD_FEATURE_FAST_DIFF')
+
     def _get_rbd_support(self):
         """Determine RBD features supported by our version of librbd."""
         old_format = True
@@ -255,24 +259,22 @@ class CephBackupDriver(driver.BackupDriver):
             old_format = False
             features |= self.rbd.RBD_FEATURE_STRIPINGV2
 
-        # journaling requires exclusive_lock; check both together
         if CONF.backup_ceph_image_journals:
-            if self._supports_exclusive_lock and self._supports_journaling:
-                old_format = False
-                features |= (self.rbd.RBD_FEATURE_EXCLUSIVE_LOCK |
-                             self.rbd.RBD_FEATURE_JOURNALING)
-            else:
-                # FIXME (tasker): when the backup manager supports loading the
-                #   driver during its initialization, this exception should be
-                #   moved to the driver's initialization so that it can stop
-                #   the service from starting when the underyling RBD does not
-                #   support the requested features.
-                LOG.error("RBD journaling not supported - unable to "
-                          "support per image mirroring in backup pool")
-                raise exception.BackupInvalidCephArgs(
-                    _("Image Journaling set but RBD backend does "
-                      "not support journaling")
-                )
+            LOG.debug("RBD journaling supported by backend and requested "
+                      "via config. Enabling it together with "
+                      "exclusive-lock")
+            old_format = False
+            features |= (self.rbd.RBD_FEATURE_EXCLUSIVE_LOCK |
+                         self.rbd.RBD_FEATURE_JOURNALING)
+
+        # NOTE(christian_rohmann): Check for fast-diff support and enable it
+        if self._supports_fast_diff:
+            LOG.debug("RBD also supports fast-diff, enabling it "
+                      "together with exclusive-lock and object-map")
+            old_format = False
+            features |= (self.rbd.RBD_FEATURE_EXCLUSIVE_LOCK |
+                         self.rbd.RBD_FEATURE_OBJECT_MAP |
+                         self.rbd.RBD_FEATURE_FAST_DIFF)
 
         return (old_format, features)
 
@@ -294,6 +296,16 @@ class CephBackupDriver(driver.BackupDriver):
         with rbd_driver.RADOSClient(self, self._ceph_backup_pool):
             pass
 
+        # NOTE(christian_rohmann): Check features required for journaling
+        if CONF.backup_ceph_image_journals:
+            if not self._supports_exclusive_lock and self._supports_journaling:
+                LOG.error("RBD journaling not supported - unable to "
+                          "support per image mirroring in backup pool")
+                raise exception.BackupInvalidCephArgs(
+                    _("Image Journaling set but RBD backend does "
+                      "not support journaling")
+                )
+
     def _connect_to_rados(self, pool=None):
         """Establish connection to the backup Ceph cluster."""
         client = eventlet.tpool.Proxy(self.rados.Rados(
@@ -806,7 +818,10 @@ class CephBackupDriver(driver.BackupDriver):
         image.
         """
         volume_id = backup.volume_id
-        backup_name = self._get_backup_base_name(volume_id, backup=backup)
+        if backup.snapshot_id:
+            backup_name = self._get_backup_base_name(volume_id)
+        else:
+            backup_name = self._get_backup_base_name(volume_id, backup=backup)
 
         with eventlet.tpool.Proxy(rbd_driver.RADOSClient(self,
                                   backup.container)) as client:
