@@ -25,7 +25,6 @@ from os_brick import executor
 from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
 from oslo_utils import excutils
-from six import moves
 
 from cinder import exception
 import cinder.privsep.lvm
@@ -34,6 +33,8 @@ from cinder import utils
 
 LOG = logging.getLogger(__name__)
 
+MINIMUM_LVM_VERSION = (2, 2, 107)
+
 
 class LVM(executor.Executor):
     """LVM object to enable various LVM related operations."""
@@ -94,6 +95,13 @@ class LVM(executor.Executor):
             _lvm_cmd_prefix.append('LVM_SUPPRESS_FD_WARNINGS=1')
         LVM.LVM_CMD_PREFIX = _lvm_cmd_prefix
 
+        lvm_version = LVM.get_lvm_version(root_helper)
+        if LVM.get_lvm_version(root_helper) < MINIMUM_LVM_VERSION:
+            LOG.warning("LVM version %(current)s is lower than the minimum "
+                        "supported version: %(supported)s",
+                        {'current': lvm_version,
+                         'supported': MINIMUM_LVM_VERSION})
+
         if create_vg and physical_volumes is not None:
             try:
                 self._create_vg(physical_volumes)
@@ -147,7 +155,7 @@ class LVM(executor.Executor):
         return exists
 
     def _create_vg(self, pv_list):
-        cinder.privsep.lvm.create_volume(self.vg_name, pv_list)
+        cinder.privsep.lvm.create_vg(self.vg_name, pv_list)
 
     def _get_thin_pool_free_space(self, vg_name, thin_pool_name):
         """Returns available thin pool free space.
@@ -278,6 +286,8 @@ class LVM(executor.Executor):
         return LVM._supports_pvs_ignoreskippedcluster
 
     @staticmethod
+    @utils.retry(retry=utils.retry_if_exit_code, retry_param=139, interval=0.5,
+                 backoff_rate=0.5)  # Bug#1901783
     def get_lv_info(root_helper, vg_name=None, lv_name=None):
         """Retrieve info about LVs (all, in a VG, or a single LV).
 
@@ -289,7 +299,8 @@ class LVM(executor.Executor):
         """
 
         cmd = LVM.LVM_CMD_PREFIX + ['lvs', '--noheadings', '--unit=g',
-                                    '-o', 'vg_name,name,size', '--nosuffix']
+                                    '-o', 'vg_name,name,size', '--nosuffix',
+                                    '--readonly']
         if lv_name is not None and vg_name is not None:
             cmd.append("%s/%s" % (vg_name, lv_name))
         elif vg_name is not None:
@@ -311,7 +322,7 @@ class LVM(executor.Executor):
         lv_list = []
         if out is not None:
             volumes = out.split()
-            iterator = moves.zip(*[iter(volumes)] * 3)  # pylint: disable=E1101
+            iterator = zip(*[iter(volumes)] * 3)  # pylint: disable=E1101
             for vg, name, size in iterator:
                 lv_list.append({"vg": vg, "name": name, "size": size})
 
@@ -644,7 +655,7 @@ class LVM(executor.Executor):
         # order to prevent a race condition.
         self._wait_for_volume_deactivation(name)
 
-    @utils.retry(exceptions=exception.VolumeNotDeactivated, retries=5,
+    @utils.retry(retry_param=exception.VolumeNotDeactivated, retries=5,
                  backoff_rate=2)
     def _wait_for_volume_deactivation(self, name):
         LOG.debug("Checking to see if volume %s has been deactivated.",
