@@ -16,9 +16,6 @@
 
 """Implementation of an image service that uses Glance as the backend"""
 
-
-from __future__ import absolute_import
-
 import copy
 import itertools
 import random
@@ -26,6 +23,8 @@ import shutil
 import sys
 import textwrap
 import time
+import typing as ty
+import urllib
 
 import glanceclient.exc
 from keystoneauth1.loading import session as ks_session
@@ -33,10 +32,8 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-import six
-from six.moves import range
-from six.moves import urllib
 
+from cinder import context
 from cinder import exception
 from cinder.i18n import _
 from cinder import service_auth
@@ -123,6 +120,8 @@ def _create_glance_client(context, netloc, use_ssl):
             config_options = {'insecure': CONF.glance_api_insecure,
                               'cacert': CONF.glance_ca_certificates_file,
                               'timeout': CONF.glance_request_timeout,
+                              'cert': CONF.glance_certfile,
+                              'key': CONF.glance_keyfile,
                               'split_loggers': CONF.split_loggers
                               }
             _SESSION = ks_session.Session().load_from_options(**config_options)
@@ -216,6 +215,7 @@ class GlanceClientWrapper(object):
                       glanceclient.exc.InvalidEndpoint,
                       glanceclient.exc.CommunicationError)
         num_attempts = 1 + CONF.glance_num_retries
+        glance_controller = kwargs.pop('controller', 'images')
         store_id = kwargs.pop('store_id', None)
         base_image_ref = kwargs.pop('base_image_ref', None)
 
@@ -230,8 +230,7 @@ class GlanceClientWrapper(object):
                 client.http_client.additional_headers = headers
 
             try:
-                controller = getattr(client,
-                                     kwargs.pop('controller', 'images'))
+                controller = getattr(client, glance_controller)
                 return getattr(controller, method)(*args, **kwargs)
             except retry_excs as e:
                 netloc = self.netloc
@@ -366,7 +365,7 @@ class GlanceImageService(object):
                     # a system call to cp could have significant performance
                     # advantages, however we do not have the path to files at
                     # this point in the abstraction.
-                    with open(parsed_url.path, "rb") as f:
+                    with open(parsed_url.path, "r") as f:
                         shutil.copyfileobj(f, data)
                     return
 
@@ -550,13 +549,13 @@ def _convert_timestamps_to_datetimes(image_meta):
 # NOTE(bcwaldon): used to store non-string data in glance metadata
 def _json_loads(properties, attr):
     prop = properties[attr]
-    if isinstance(prop, six.string_types):
+    if isinstance(prop, str):
         properties[attr] = jsonutils.loads(prop)
 
 
 def _json_dumps(properties, attr):
     prop = properties[attr]
-    if not isinstance(prop, six.string_types):
+    if not isinstance(prop, str):
         properties[attr] = jsonutils.dumps(prop)
 
 
@@ -624,14 +623,14 @@ def _reraise_translated_image_exception(image_id):
     """Transform the exception for the image but keep its traceback intact."""
     _exc_type, exc_value, exc_trace = sys.exc_info()
     new_exc = _translate_image_exception(image_id, exc_value)
-    six.reraise(type(new_exc), new_exc, exc_trace)
+    raise new_exc.with_traceback(exc_trace)
 
 
 def _reraise_translated_exception():
     """Transform the exception but keep its traceback intact."""
     _exc_type, exc_value, exc_trace = sys.exc_info()
     new_exc = _translate_plain_exception(exc_value)
-    six.reraise(type(new_exc), new_exc, exc_trace)
+    raise new_exc.with_traceback(exc_trace)
 
 
 def _translate_image_exception(image_id, exc_value):
@@ -656,7 +655,8 @@ def _translate_plain_exception(exc_value):
     return exc_value
 
 
-def get_remote_image_service(context, image_href):
+def get_remote_image_service(context: context.RequestContext,
+                             image_href) -> ty.Tuple[GlanceImageService, str]:
     """Create an image_service and parse the id from the given image_href.
 
     The image_href param can be an href of the form
