@@ -43,7 +43,6 @@ from oslo_utils import imageutils
 from oslo_utils import timeutils
 from oslo_utils import units
 import psutil
-import six
 
 from cinder import exception
 from cinder.i18n import _
@@ -164,13 +163,63 @@ def get_qemu_img_version():
 
 
 def qemu_img_supports_force_share():
-    return get_qemu_img_version() > [2, 10, 0]
+    return get_qemu_img_version() >= QEMU_IMG_MIN_FORCE_SHARE_VERSION
+
+
+def _get_qemu_convert_luks_cmd(src, dest, out_format, src_format=None,
+                               out_subformat=None, cache_mode=None,
+                               prefix=None, cipher_spec=None,
+                               passphrase_file=None,
+                               src_passphrase_file=None):
+
+    cmd = ['qemu-img', 'convert']
+
+    if prefix:
+        cmd = list(prefix) + cmd
+
+    if cache_mode:
+        cmd += ('-t', cache_mode)
+
+    obj1 = ['--object',
+            'secret,id=sec1,format=raw,file=%s' % src_passphrase_file]
+    obj2 = ['--object',
+            'secret,id=sec2,format=raw,file=%s' % passphrase_file]
+
+    src_opts = 'encrypt.format=luks,encrypt.key-secret=sec1,' \
+               'file.filename=%s' % src
+
+    image_opts = ['--image-opts', src_opts]
+    output_opts = ['-O', 'luks', '-o', 'key-secret=sec2', dest]
+
+    command = cmd + obj1 + obj2 + image_opts + output_opts
+    return command
 
 
 def _get_qemu_convert_cmd(src, dest, out_format, src_format=None,
                           out_subformat=None, cache_mode=None,
                           prefix=None, cipher_spec=None,
-                          passphrase_file=None, compress=False):
+                          passphrase_file=None, compress=False,
+                          src_passphrase_file=None):
+
+    if src_passphrase_file is not None:
+        if passphrase_file is None:
+            message = _("Can't create unencrypted volume %(format)s "
+                        "from an encrypted source volume."
+                        ) % {'format': out_format}
+            LOG.error(message)
+            # TODO(enriquetaso): handle encrypted->unencrypted
+            raise exception.NotSupportedOperation(operation=message)
+        return _get_qemu_convert_luks_cmd(
+            src,
+            dest,
+            out_format,
+            src_format=src_format,
+            out_subformat=out_subformat,
+            cache_mode=cache_mode,
+            prefix=None,
+            cipher_spec=cipher_spec,
+            passphrase_file=passphrase_file,
+            src_passphrase_file=src_passphrase_file)
 
     if out_format == 'vhd':
         # qemu-img still uses the legacy vpc name
@@ -240,7 +289,8 @@ def check_qemu_img_version(minimum_version):
 def _convert_image(prefix, source, dest, out_format,
                    out_subformat=None, src_format=None,
                    run_as_root=True, cipher_spec=None,
-                   passphrase_file=None, compress=False):
+                   passphrase_file=None, compress=False,
+                   src_passphrase_file=None):
     """Convert image to other format.
 
     NOTE: If the qemu-img convert command fails and this function raises an
@@ -257,6 +307,8 @@ def _convert_image(prefix, source, dest, out_format,
     :param cipher_spec: encryption details
     :param passphrase_file: filename containing luks passphrase
     :param compress: compress w/ qemu-img when possible (best effort)
+    :param src_passphrase_file: filename containing source volume's
+                                luks passphrase
     """
 
     # Check whether O_DIRECT is supported and set '-t none' if it is
@@ -285,7 +337,8 @@ def _convert_image(prefix, source, dest, out_format,
                                 prefix=prefix,
                                 cipher_spec=cipher_spec,
                                 passphrase_file=passphrase_file,
-                                compress=compress)
+                                compress=compress,
+                                src_passphrase_file=src_passphrase_file)
 
     start_time = timeutils.utcnow()
 
@@ -337,7 +390,7 @@ def _convert_image(prefix, source, dest, out_format,
 def convert_image(source, dest, out_format, out_subformat=None,
                   src_format=None, run_as_root=True, throttle=None,
                   cipher_spec=None, passphrase_file=None,
-                  compress=False):
+                  compress=False, src_passphrase_file=None):
     if not throttle:
         throttle = throttling.Throttle.get_default()
     with throttle.subcommand(source, dest) as throttle_cmd:
@@ -349,12 +402,16 @@ def convert_image(source, dest, out_format, out_subformat=None,
                        run_as_root=run_as_root,
                        cipher_spec=cipher_spec,
                        passphrase_file=passphrase_file,
-                       compress=compress)
+                       compress=compress,
+                       src_passphrase_file=src_passphrase_file)
 
 
-def resize_image(source, size, run_as_root=False):
+def resize_image(source, size, run_as_root=False, file_format=None):
     """Changes the virtual size of the image."""
-    cmd = ('qemu-img', 'resize', source, '%sG' % size)
+    if file_format:
+        cmd = ('qemu-img', 'resize', '-f', file_format, source, '%sG' % size)
+    else:
+        cmd = ('qemu-img', 'resize', source, '%sG' % size)
     utils.execute(*cmd, run_as_root=run_as_root)
 
 
@@ -425,8 +482,7 @@ def verify_glance_image_signature(context, image_service, image_id, path):
                     message = _('Failed to verify signature for '
                                 'image: %(image)s due to '
                                 'error: %(error)s ') % {'image': image_id,
-                                                        'error':
-                                                            six.text_type(ex)}
+                                                        'error': ex}
                     LOG.error(message)
                     raise exception.ImageSignatureVerificationException(
                         reason=message)
