@@ -14,11 +14,7 @@
 
 """Cinder common internal object model"""
 
-try:
-    from collections.abc import Callable
-except ImportError:
-    from collections import Callable
-
+from collections import abc
 import contextlib
 import datetime
 
@@ -167,7 +163,7 @@ class CinderObjectRegistry(base.VersionedObjectRegistry):
 
         # If registering class has a callable initialization method, call it.
         if isinstance(getattr(cls, 'cinder_ovo_cls_init', None),
-                      Callable):
+                      abc.Callable):
             cls.cinder_ovo_cls_init()
 
 
@@ -280,7 +276,7 @@ class CinderPersistentObject(object):
         # registration.
         try:
             cls.model = db.get_model_for_versioned_object(cls)
-        except (ImportError, AttributeError) as e:
+        except (ImportError, AttributeError):
             msg = _("Couldn't find ORM model for Persistent Versioned "
                     "Object %s.") % cls.obj_name()
             LOG.exception("Failed to initialize object.")
@@ -578,7 +574,7 @@ class CinderObjectSerializer(base.VersionedObjectSerializer):
             entity = self._process_iterable(context, self.serialize_entity,
                                             entity)
         elif (hasattr(entity, 'obj_to_primitive') and
-              isinstance(entity.obj_to_primitive, Callable)):
+              isinstance(entity.obj_to_primitive, abc.Callable)):
             # NOTE(dulek): Backport outgoing object to the capped version.
             backport_ver = self._get_capped_obj_version(entity)
             entity = entity.obj_to_primitive(backport_ver, self.manifest)
