@@ -13,20 +13,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import HTTPStatus
+from unittest import mock
 
-import mock
 from oslo_serialization import jsonutils
-from six.moves import http_client
 import webob
 
 from cinder import context
 from cinder.objects import fields
 from cinder.policies import snapshots as snap_policy
-from cinder import test
 from cinder.tests.unit.api import fakes
 from cinder.tests.unit import fake_constants as fake
 from cinder.tests.unit import fake_snapshot
 from cinder.tests.unit import fake_volume
+from cinder.tests.unit import test
 
 
 UUID1 = fake.SNAPSHOT_ID
@@ -101,12 +101,12 @@ class ExtendedSnapshotAttributesTest(test.TestCase):
         url = '/v2/%s/snapshots/%s' % (fake.PROJECT_ID, UUID1)
         res = self._make_request(url)
 
-        self.assertEqual(http_client.OK, res.status_int)
+        self.assertEqual(HTTPStatus.OK, res.status_int)
         self.assertSnapshotAttributes(self._get_snapshot(res.body),
                                       project_id=fake.PROJECT_ID,
                                       progress='0%')
-        calls = [mock.call(snap_policy.GET_POLICY), mock.call(
-            snap_policy.EXTEND_ATTRIBUTE, fatal=False)]
+        calls = [mock.call(snap_policy.GET_POLICY, target_obj=snapshot_obj),
+                 mock.call(snap_policy.EXTEND_ATTRIBUTE, fatal=False)]
         mock_authorize.assert_has_calls(calls)
 
     @mock.patch('cinder.context.RequestContext.authorize')
@@ -115,7 +115,7 @@ class ExtendedSnapshotAttributesTest(test.TestCase):
         res = self._make_request(url)
         mock_authorize.return_value = False
 
-        self.assertEqual(http_client.OK, res.status_int)
+        self.assertEqual(HTTPStatus.OK, res.status_int)
         for snapshot in self._get_snapshots(res.body):
             self.assertSnapshotAttributes(snapshot,
                                           project_id=fake.PROJECT_ID,
