@@ -12,6 +12,7 @@
 #    under the License.
 
 import datetime
+from http import HTTPStatus
 import json
 from unittest import mock
 
@@ -21,7 +22,6 @@ import iso8601
 from oslo_serialization import jsonutils
 from oslo_utils import strutils
 from oslo_utils import timeutils
-from six.moves import http_client
 import webob
 
 from cinder.api import api_utils
@@ -31,6 +31,7 @@ from cinder.api import microversions as mv
 from cinder.api.v2.views.volumes import ViewBuilder
 from cinder.api.v3 import volumes
 from cinder.backup import api as backup_api
+from cinder.common import constants as cinder_constants
 from cinder import context
 from cinder import db
 from cinder import exception
@@ -38,18 +39,41 @@ from cinder.group import api as group_api
 from cinder import objects
 from cinder.objects import fields
 from cinder.policies import volumes as policy
-from cinder import test
 from cinder.tests.unit.api import fakes
 from cinder.tests.unit.api.v2 import fakes as v2_fakes
 from cinder.tests.unit.api.v2 import test_volumes as v2_test_volumes
 from cinder.tests.unit import fake_constants as fake
 from cinder.tests.unit.image import fake as fake_image
+from cinder.tests.unit import test
 from cinder.tests.unit import utils as test_utils
 from cinder.volume import api as volume_api
 from cinder.volume import api as vol_get
 
 DEFAULT_AZ = "zone1:host1"
 
+# DDT data for testing whether an 'encryption_key_id' should appear in a
+# volume's or backup's details (also used by test_backups.py).
+ENCRYPTION_KEY_ID_IN_DETAILS = {
+    'expected_in_details': True,
+    'encryption_key_id': fake.ENCRYPTION_KEY_ID,
+    'version': mv.ENCRYPTION_KEY_ID_IN_DETAILS,
+}, {
+    # No encryption ID to display
+    'expected_in_details': False,
+    'encryption_key_id': None,
+    'version': mv.ENCRYPTION_KEY_ID_IN_DETAILS,
+}, {
+    # Fixed key ID should not be displayed
+    'expected_in_details': False,
+    'encryption_key_id': cinder_constants.FIXED_KEY_ID,
+    'version': mv.ENCRYPTION_KEY_ID_IN_DETAILS,
+}, {
+    # Unsupported microversion
+    'expected_in_details': False,
+    'encryption_key_id': fake.ENCRYPTION_KEY_ID,
+    'version': mv.get_prior_version(mv.ENCRYPTION_KEY_ID_IN_DETAILS),
+}
+
 
 @ddt.ddt
 class VolumeApiTest(test.TestCase):
@@ -748,7 +772,7 @@ class VolumeApiTest(test.TestCase):
         res = req.get_response(fakes.wsgi_app(
             fake_auth_context=self.ctxt))
         res_dict = jsonutils.loads(res.body)
-        self.assertEqual(http_client.ACCEPTED, res.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, res.status_int)
         self.assertIn('id', res_dict['volume'])
 
     @ddt.data('fake_host', '', 1234, '          ')
@@ -856,6 +880,26 @@ class VolumeApiTest(test.TestCase):
         else:
             self.assertNotIn('provider_id', res_dict['volume'])
 
+    @ddt.data(*ENCRYPTION_KEY_ID_IN_DETAILS)
+    @ddt.unpack
+    def test_volume_show_with_encryption_key_id(self,
+                                                expected_in_details,
+                                                encryption_key_id,
+                                                version):
+        volume = test_utils.create_volume(self.ctxt,
+                                          testcase_instance=self,
+                                          volume_type_id=None,
+                                          encryption_key_id=encryption_key_id)
+
+        req = fakes.HTTPRequest.blank('/v3/volumes/%s' % volume.id,
+                                      version=version)
+        volume_details = self.controller.show(req, volume.id)['volume']
+
+        if expected_in_details:
+            self.assertIn('encryption_key_id', volume_details)
+        else:
+            self.assertNotIn('encryption_key_id', volume_details)
+
     def _fake_create_volume(self, size=1):
         vol = {
             'display_name': 'fake_volume1',
@@ -992,7 +1036,7 @@ class VolumeApiTest(test.TestCase):
 
         # get_attachments should only return attachments with the
         # attached status = ATTACHED
-        attachments = ViewBuilder()._get_attachments(fake_volume)
+        attachments = ViewBuilder()._get_attachments(fake_volume, True)
 
         self.assertEqual(1, len(attachments))
         self.assertEqual(fake.UUID3, attachments[0]['attachment_id'])
@@ -1002,6 +1046,10 @@ class VolumeApiTest(test.TestCase):
         self.assertEqual('na', attachments[0]['device'])
         self.assertEqual(att_time, attachments[0]['attached_at'])
 
+        # When admin context is false (non-admin), host_name will be None
+        attachments = ViewBuilder()._get_attachments(fake_volume, False)
+        self.assertIsNone(attachments[0]['host_name'])
+
     @ddt.data(('created_at=gt:', 0), ('created_at=lt:', 2))
     @ddt.unpack
     def test_volume_index_filter_by_created_at_with_gt_and_lt(self, change,
