@@ -11,8 +11,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-from six.moves import http_client
+from http import HTTPStatus
+from unittest import mock
 
 from cinder.api import microversions as mv
 from cinder.tests.unit import fake_constants
@@ -40,7 +40,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-extend": {"new_size": "2"}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     def test_owner_can_extend_volume(self):
         user_context = self.user_context
@@ -53,7 +53,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-extend": {"new_size": "2"}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.API, 'get')
     def test_owner_cannot_extend_volume_for_others(self, mock_volume):
@@ -69,7 +69,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-extend": {"new_size": "2"}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
     def test_admin_can_extend_attached_volume(self):
         admin_context = self.admin_context
@@ -83,7 +83,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         response = self._get_request_response(
             admin_context, path, 'POST', body=body,
             microversion=mv.VOLUME_EXTEND_INUSE)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     def test_owner_can_extend_attached_volume(self):
         user_context = self.user_context
@@ -97,7 +97,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         response = self._get_request_response(
             user_context, path, 'POST', body=body,
             microversion=mv.VOLUME_EXTEND_INUSE)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.API, 'get')
     def test_owner_cannot_extend_attached_volume_for_others(self, mock_volume):
@@ -114,7 +114,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         response = self._get_request_response(
             non_owner_context, path, 'POST', body=body,
             microversion=mv.VOLUME_EXTEND_INUSE)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
     def test_admin_can_retype_volume(self):
         admin_context = self.admin_context
@@ -129,7 +129,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                               "migration_policy": "never"}}
         response = self._get_request_response(
             admin_context, path, 'POST', body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     def test_owner_can_retype_volume(self):
         user_context = self.user_context
@@ -144,7 +144,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                               "migration_policy": "never"}}
         response = self._get_request_response(
             user_context, path, 'POST', body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.API, 'get')
     def test_owner_cannot_retype_volume_for_others(self, mock_volume):
@@ -162,7 +162,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                               "migration_policy": "never"}}
         response = self._get_request_response(
             non_owner_context, path, 'POST', body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
     def test_admin_can_update_readonly(self):
         admin_context = self.admin_context
@@ -177,7 +177,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-update_readonly_flag": {"readonly": "True"}}
         response = self._get_request_response(
             admin_context, path, 'POST', body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     def test_owner_can_update_readonly(self):
         user_context = self.user_context
@@ -192,7 +192,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-update_readonly_flag": {"readonly": "True"}}
         response = self._get_request_response(
             user_context, path, 'POST', body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.API, 'get')
     def test_owner_cannot_update_readonly_for_others(self, mock_volume):
@@ -209,7 +209,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-update_readonly_flag": {"readonly": "True"}}
         response = self._get_request_response(
             non_owner_context, path, 'POST', body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
     @mock.patch.object(volume_api.API, 'get_volume')
     def test_admin_can_force_delete_volumes(self, mock_volume):
@@ -225,7 +225,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
 
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.API, 'get_volume')
     def test_nonadmin_cannot_force_delete_volumes(self, mock_volume):
@@ -241,7 +241,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
 
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI, 'attach_volume')
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI, 'detach_volume')
@@ -257,12 +257,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                               "mountpoint": "/dev/vdc"}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
         body = {"os-detach": {}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI, 'attach_volume')
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI, 'detach_volume')
@@ -278,12 +278,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                               "mountpoint": "/dev/vdc"}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
         body = {"os-detach": {}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI, 'attach_volume')
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI, 'detach_volume')
@@ -304,12 +304,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                               "mountpoint": "/dev/vdc"}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
         body = {"os-detach": {}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
     def test_admin_can_reserve_unreserve_volume(self):
         admin_context = self.admin_context
@@ -322,12 +322,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-reserve": {}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
         body = {"os-unreserve": {}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     def test_owner_can_reserve_unreserve_volume(self):
         user_context = self.user_context
@@ -340,12 +340,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-reserve": {}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
         body = {"os-unreserve": {}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.API, 'get')
     def test_owner_cannot_reserve_unreserve_volume_for_others(self,
@@ -363,12 +363,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                               "mountpoint": "/dev/vdc"}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
         body = {"os-detach": {}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI,
                        'initialize_connection')
@@ -385,12 +385,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-initialize_connection": {'connector': {}}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.OK, response.status_int)
+        self.assertEqual(HTTPStatus.OK, response.status_int)
 
         body = {"os-terminate_connection": {'connector': {}}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI,
                        'initialize_connection')
@@ -407,12 +407,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-initialize_connection": {'connector': {}}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.OK, response.status_int)
+        self.assertEqual(HTTPStatus.OK, response.status_int)
 
         body = {"os-terminate_connection": {'connector': {}}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.volume_rpcapi.VolumeAPI,
                        'initialize_connection')
@@ -435,12 +435,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-initialize_connection": {'connector': {}}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
         body = {"os-terminate_connection": {'connector': {}}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
     def test_admin_can_begin_roll_detaching(self):
         admin_context = self.admin_context
@@ -454,12 +454,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-begin_detaching": {}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
         body = {"os-roll_detaching": {}}
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     def test_owner_can_begin_roll_detaching(self):
         user_context = self.user_context
@@ -473,12 +473,12 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-begin_detaching": {}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
         body = {"os-roll_detaching": {}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.ACCEPTED, response.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
     @mock.patch.object(volume_api.API, 'get')
     def test_owner_cannot_begin_roll_detaching_for_others(self, mock_volume):
@@ -495,9 +495,9 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         body = {"os-begin_detaching": {}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
 
         body = {"os-roll_detaching": {}}
         response = self._get_request_response(non_owner_context, path, 'POST',
                                               body=body)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
