@@ -17,7 +17,9 @@
 
 
 import datetime
+import functools
 import io
+import time
 from unittest import mock
 
 from castellan import key_manager
@@ -25,22 +27,22 @@ import ddt
 from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_utils import units
-import six
 
 from cinder import context
 from cinder import db
 from cinder.db.sqlalchemy import models
 from cinder import exception
 from cinder.objects import fields
-from cinder import test
 from cinder.tests.unit.backup import fake_backup
 from cinder.tests.unit import fake_constants as fake
 from cinder.tests.unit import fake_group
 from cinder.tests.unit import fake_snapshot
 from cinder.tests.unit import fake_volume
 from cinder.tests.unit.image import fake as fake_image
+from cinder.tests.unit import test
 from cinder.tests.unit import utils as test_utils
 from cinder import utils
+from cinder.volume import driver
 from cinder.volume import throttling
 from cinder.volume import volume_types
 from cinder.volume import volume_utils
@@ -167,8 +169,8 @@ class NotifyUsageTestCase(test.TestCase):
             'created_at': '2014-12-11T10:10:00+00:00',
             'status': fields.SnapshotStatus.ERROR,
             'deleted': '',
-            'metadata': six.text_type({'fake_snap_meta_key':
-                                      u'fake_snap_meta_value'}),
+            'metadata': str({'fake_snap_meta_key':
+                            u'fake_snap_meta_value'}),
         }
         self.assertDictEqual(expected_snapshot, usage_info)
 
@@ -212,8 +214,8 @@ class NotifyUsageTestCase(test.TestCase):
             'created_at': mock.ANY,
             'status': fields.SnapshotStatus.ERROR,
             'deleted': '',
-            'metadata': six.text_type({'fake_snap_meta_key':
-                                      u'fake_snap_meta_value'}),
+            'metadata': str({'fake_snap_meta_key':
+                            u'fake_snap_meta_value'}),
         }
         self.assertDictEqual(expected_snapshot, usage_info)
 
@@ -1083,19 +1085,6 @@ class VolumeUtilsTestCase(test.TestCase):
             else:
                 self.assertEqual(float(max_over_subscription_ratio), mosr)
 
-    def test_make_initiator_target_all2all_map(self):
-        initiator_wwpns = ['ff00000000000000', 'ff00000000000001']
-        target_wwpns = ['bb00000000000000', 'bb00000000000001']
-
-        expected = {
-            'ff00000000000000': ['bb00000000000000', 'bb00000000000001'],
-            'ff00000000000001': ['bb00000000000000', 'bb00000000000001']
-        }
-
-        ret = volume_utils.make_initiator_target_all2all_map(initiator_wwpns,
-                                                             target_wwpns)
-        self.assertEqual(ret, expected)
-
     def test_check_image_metadata(self):
         image_meta = {'id': 1, 'min_disk': 3, 'status': 'active',
                       'size': 1 * units.Gi}
@@ -1105,7 +1094,7 @@ class VolumeUtilsTestCase(test.TestCase):
                                 image_meta,
                                 vol_size)
         self.assertIn("Volume size 2GB cannot be smaller than the image "
-                      "minDisk size 3GB.", six.text_type(res))
+                      "minDisk size 3GB.", str(res))
 
         image_meta['size'] = 3 * units.Gi
         res = self.assertRaises(exception.InvalidInput,
@@ -1113,14 +1102,14 @@ class VolumeUtilsTestCase(test.TestCase):
                                 image_meta,
                                 vol_size)
         self.assertIn("Size of specified image 3GB is larger than volume "
-                      "size 2GB.", six.text_type(res))
+                      "size 2GB.", str(res))
 
         image_meta['status'] = 'error'
         res = self.assertRaises(exception.InvalidInput,
                                 volume_utils.check_image_metadata,
                                 image_meta,
                                 vol_size)
-        self.assertIn("Image 1 is not active.", six.text_type(res))
+        self.assertIn("Image 1 is not active.", str(res))
 
     def test_enable_volume_bootable(self):
         ctxt = context.get_admin_context()
@@ -1210,3 +1199,359 @@ class VolumeUtilsTestCase(test.TestCase):
                               db,
                               volume,
                               mock.sentinel.context)
+
+    @mock.patch('cinder.volume.volume_utils.CONF.list_all_sections')
+    def test_get_backend_configuration_backend_stanza_not_found(self,
+                                                                mock_conf):
+        mock_conf.return_value = []
+        self.assertRaises(exception.ConfigNotFound,
+                          volume_utils.get_backend_configuration,
+                          'backendA')
+
+        mock_conf.return_value = ['backendB']
+        self.assertRaises(exception.ConfigNotFound,
+                          volume_utils.get_backend_configuration,
+                          'backendA')
+
+    @mock.patch('cinder.volume.volume_utils.CONF.list_all_sections')
+    @mock.patch('cinder.volume.configuration.Configuration')
+    def test_get_backend_configuration_backend_opts(self, mock_configuration,
+                                                    mock_conf):
+        mock_conf.return_value = ['backendA']
+        volume_utils.get_backend_configuration('backendA', ['someFakeOpt'])
+        mock_configuration.assert_called_with(driver.volume_opts,
+                                              config_group='backendA')
+        mock_configuration.return_value.\
+            append_config_values.assert_called_with(['someFakeOpt'])
+
+    @mock.patch('cinder.volume.volume_utils.CONF.list_all_sections')
+    @mock.patch('cinder.volume.configuration.Configuration')
+    def test_get_backend_configuration(self, mock_configuration, mock_conf):
+        mock_conf.return_value = ['backendA']
+        volume_utils.get_backend_configuration('backendA')
+        mock_configuration.assert_called_with(driver.volume_opts,
+                                              config_group='backendA')
+
+
+@ddt.ddt
+class LogTracingTestCase(test.TestCase):
+
+    def test_utils_setup_tracing(self):
+        self.mock_object(volume_utils, 'LOG')
+
+        volume_utils.setup_tracing(None)
+        self.assertFalse(volume_utils.TRACE_API)
+        self.assertFalse(volume_utils.TRACE_METHOD)
+        self.assertEqual(0, volume_utils.LOG.warning.call_count)
+
+        volume_utils.setup_tracing(['method'])
+        self.assertFalse(volume_utils.TRACE_API)
+        self.assertTrue(volume_utils.TRACE_METHOD)
+        self.assertEqual(0, volume_utils.LOG.warning.call_count)
+
+        volume_utils.setup_tracing(['method', 'api'])
+        self.assertTrue(volume_utils.TRACE_API)
+        self.assertTrue(volume_utils.TRACE_METHOD)
+        self.assertEqual(0, volume_utils.LOG.warning.call_count)
+
+    def test_utils_setup_tracing_invalid_key(self):
+        self.mock_object(volume_utils, 'LOG')
+
+        volume_utils.setup_tracing(['fake'])
+
+        self.assertFalse(volume_utils.TRACE_API)
+        self.assertFalse(volume_utils.TRACE_METHOD)
+        self.assertEqual(1, volume_utils.LOG.warning.call_count)
+
+    def test_utils_setup_tracing_valid_and_invalid_key(self):
+        self.mock_object(volume_utils, 'LOG')
+
+        volume_utils.setup_tracing(['method', 'fake'])
+
+        self.assertFalse(volume_utils.TRACE_API)
+        self.assertTrue(volume_utils.TRACE_METHOD)
+        self.assertEqual(1, volume_utils.LOG.warning.call_count)
+
+    def test_trace_no_tracing(self):
+        self.mock_object(volume_utils, 'LOG')
+
+        @volume_utils.trace_method
+        def _trace_test_method(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(None)
+
+        result = _trace_test_method()
+
+        self.assertEqual('OK', result)
+        self.assertEqual(0, volume_utils.LOG.debug.call_count)
+
+    def test_utils_trace_method(self):
+        self.mock_object(volume_utils, 'LOG')
+
+        @volume_utils.trace_method
+        def _trace_test_method(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(['method'])
+
+        result = _trace_test_method()
+        self.assertEqual('OK', result)
+        self.assertEqual(2, volume_utils.LOG.debug.call_count)
+
+    def test_utils_trace_api(self):
+        self.mock_object(volume_utils, 'LOG')
+
+        @volume_utils.trace_api
+        def _trace_test_api(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(['api'])
+
+        result = _trace_test_api()
+        self.assertEqual('OK', result)
+        self.assertEqual(2, volume_utils.LOG.debug.call_count)
+
+    def test_utils_trace_api_filtered(self):
+        self.mock_object(volume_utils, 'LOG')
+
+        def filter_func(all_args):
+            return False
+
+        @volume_utils.trace_api(filter_function=filter_func)
+        def _trace_test_api(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(['api'])
+
+        result = _trace_test_api()
+        self.assertEqual('OK', result)
+        self.assertEqual(0, volume_utils.LOG.debug.call_count)
+
+    def test_utils_trace_filtered(self):
+        self.mock_object(volume_utils, 'LOG')
+
+        def filter_func(all_args):
+            return False
+
+        @volume_utils.trace(filter_function=filter_func)
+        def _trace_test(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(['api'])
+
+        result = _trace_test()
+        self.assertEqual('OK', result)
+        self.assertEqual(0, volume_utils.LOG.debug.call_count)
+
+    def test_utils_trace_method_default_logger(self):
+        mock_log = self.mock_object(volume_utils, 'LOG')
+
+        @volume_utils.trace_method
+        def _trace_test_method_custom_logger(*args, **kwargs):
+            return 'OK'
+        volume_utils.setup_tracing(['method'])
+
+        result = _trace_test_method_custom_logger()
+
+        self.assertEqual('OK', result)
+        self.assertEqual(2, mock_log.debug.call_count)
+
+    def test_utils_trace_method_inner_decorator(self):
+        mock_logging = self.mock_object(volume_utils, 'logging')
+        mock_log = mock.Mock()
+        mock_log.isEnabledFor = lambda x: True
+        mock_logging.getLogger = mock.Mock(return_value=mock_log)
+
+        def _test_decorator(f):
+            def blah(*args, **kwargs):
+                return f(*args, **kwargs)
+            return blah
+
+        @_test_decorator
+        @volume_utils.trace_method
+        def _trace_test_method(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(['method'])
+
+        result = _trace_test_method(self)
+
+        self.assertEqual('OK', result)
+        self.assertEqual(2, mock_log.debug.call_count)
+        # Ensure the correct function name was logged
+        for call in mock_log.debug.call_args_list:
+            self.assertIn('_trace_test_method', str(call))
+            self.assertNotIn('blah', str(call))
+
+    def test_utils_trace_method_outer_decorator(self):
+        mock_logging = self.mock_object(volume_utils, 'logging')
+        mock_log = mock.Mock()
+        mock_log.isEnabledFor = lambda x: True
+        mock_logging.getLogger = mock.Mock(return_value=mock_log)
+
+        def _test_decorator(f):
+            def blah(*args, **kwargs):
+                return f(*args, **kwargs)
+            return blah
+
+        @volume_utils.trace_method
+        @_test_decorator
+        def _trace_test_method(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(['method'])
+
+        result = _trace_test_method(self)
+
+        self.assertEqual('OK', result)
+        self.assertEqual(2, mock_log.debug.call_count)
+        # Ensure the incorrect function name was logged
+        for call in mock_log.debug.call_args_list:
+            self.assertNotIn('_trace_test_method', str(call))
+            self.assertIn('blah', str(call))
+
+    def test_utils_trace_method_outer_decorator_with_functools(self):
+        mock_log = mock.Mock()
+        mock_log.isEnabledFor = lambda x: True
+        self.mock_object(utils.logging, 'getLogger', mock_log)
+        mock_log = self.mock_object(volume_utils, 'LOG')
+
+        def _test_decorator(f):
+            @functools.wraps(f)
+            def wraps(*args, **kwargs):
+                return f(*args, **kwargs)
+            return wraps
+
+        @volume_utils.trace_method
+        @_test_decorator
+        def _trace_test_method(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(['method'])
+
+        result = _trace_test_method()
+
+        self.assertEqual('OK', result)
+        self.assertEqual(2, mock_log.debug.call_count)
+        # Ensure the incorrect function name was logged
+        for call in mock_log.debug.call_args_list:
+            self.assertIn('_trace_test_method', str(call))
+            self.assertNotIn('wraps', str(call))
+
+    def test_utils_trace_method_with_exception(self):
+        self.LOG = self.mock_object(volume_utils, 'LOG')
+
+        @volume_utils.trace_method
+        def _trace_test_method(*args, **kwargs):
+            raise exception.APITimeout('test message')
+
+        volume_utils.setup_tracing(['method'])
+
+        self.assertRaises(exception.APITimeout, _trace_test_method)
+
+        exception_log = self.LOG.debug.call_args_list[1]
+        self.assertIn('exception', str(exception_log))
+        self.assertIn('test message', str(exception_log))
+
+    def test_utils_trace_method_with_time(self):
+        mock_logging = self.mock_object(volume_utils, 'logging')
+        mock_log = mock.Mock()
+        mock_log.isEnabledFor = lambda x: True
+        mock_logging.getLogger = mock.Mock(return_value=mock_log)
+
+        mock_time = mock.Mock(side_effect=[3.1, 6])
+        self.mock_object(time, 'time', mock_time)
+
+        @volume_utils.trace_method
+        def _trace_test_method(*args, **kwargs):
+            return 'OK'
+
+        volume_utils.setup_tracing(['method'])
+
+        result = _trace_test_method(self)
+
+        self.assertEqual('OK', result)
+        return_log = mock_log.debug.call_args_list[1]
+        self.assertIn('2900', str(return_log))
+
+    def test_utils_trace_wrapper_class(self):
+        mock_logging = self.mock_object(volume_utils, 'logging')
+        mock_log = mock.Mock()
+        mock_log.isEnabledFor = lambda x: True
+        mock_logging.getLogger = mock.Mock(return_value=mock_log)
+
+        volume_utils.setup_tracing(['method'])
+
+        class MyClass(object, metaclass=volume_utils.TraceWrapperMetaclass):
+            def trace_test_method(self):
+                return 'OK'
+
+        test_class = MyClass()
+        result = test_class.trace_test_method()
+
+        self.assertEqual('OK', result)
+        self.assertEqual(2, mock_log.debug.call_count)
+
+    def test_utils_trace_method_with_password_dict(self):
+        mock_logging = self.mock_object(volume_utils, 'logging')
+        mock_log = mock.Mock()
+        mock_log.isEnabledFor = lambda x: True
+        mock_logging.getLogger = mock.Mock(return_value=mock_log)
+
+        @volume_utils.trace_method
+        def _trace_test_method(*args, **kwargs):
+            return {'something': 'test',
+                    'password': 'Now you see me'}
+
+        volume_utils.setup_tracing(['method'])
+        result = _trace_test_method(self)
+        expected_unmasked_dict = {'something': 'test',
+                                  'password': 'Now you see me'}
+
+        self.assertEqual(expected_unmasked_dict, result)
+        self.assertEqual(2, mock_log.debug.call_count)
+        self.assertIn("'password': '***'",
+                      str(mock_log.debug.call_args_list[1]))
+
+    def test_utils_trace_method_with_password_str(self):
+        mock_logging = self.mock_object(volume_utils, 'logging')
+        mock_log = mock.Mock()
+        mock_log.isEnabledFor = lambda x: True
+        mock_logging.getLogger = mock.Mock(return_value=mock_log)
+
+        @volume_utils.trace_method
+        def _trace_test_method(*args, **kwargs):
+            return "'adminPass': 'Now you see me'"
+
+        volume_utils.setup_tracing(['method'])
+        result = _trace_test_method(self)
+        expected_unmasked_str = "'adminPass': 'Now you see me'"
+
+        self.assertEqual(expected_unmasked_str, result)
+        self.assertEqual(2, mock_log.debug.call_count)
+        self.assertIn("'adminPass': '***'",
+                      str(mock_log.debug.call_args_list[1]))
+
+    def test_utils_trace_method_with_password_in_formal_params(self):
+        mock_logging = self.mock_object(volume_utils, 'logging')
+        mock_log = mock.Mock()
+        mock_log.isEnabledFor = lambda x: True
+        mock_logging.getLogger = mock.Mock(return_value=mock_log)
+
+        @volume_utils.trace
+        def _trace_test_method(*args, **kwargs):
+            self.assertEqual('verybadpass',
+                             kwargs['test_args']['data']['password'])
+            pass
+
+        test_args = {
+            'data': {
+                'password': 'verybadpass'
+            }
+        }
+        _trace_test_method(self, test_args=test_args)
+
+        self.assertEqual(2, mock_log.debug.call_count)
+        self.assertIn("'password': '***'",
+                      str(mock_log.debug.call_args_list[0]))
