@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2019 Dell Inc. or its subsidiaries.
+# Copyright (c) 2020 Dell Inc. or its subsidiaries.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,6 +14,7 @@
 #    under the License.
 
 from copy import deepcopy
+import random
 
 import six
 
@@ -78,7 +79,7 @@ class PowerMaxData(object):
     rdf_group_no_2 = '71'
     rdf_group_no_3 = '72'
     rdf_group_no_4 = '73'
-    u4v_version = '91'
+    u4v_version = '92'
     storagegroup_name_source = 'Grp_source_sg'
     storagegroup_name_target = 'Grp_target_sg'
     group_snapshot_name = 'Grp_snapshot'
@@ -92,15 +93,20 @@ class PowerMaxData(object):
     next_gen_ucode = 5978
     gvg_group_id = 'test-gvg'
     sg_tags = 'production,test'
+    snap_id = 118749976833
+    snap_id_2 = 118749976834
 
     # connector info
     wwpn1 = '123456789012345'
     wwpn2 = '123456789054321'
     wwnn1 = '223456789012345'
-    initiator = 'iqn.1993-08.org.debian: 01: 222'
-    ip, ip2 = u'123.456.7.8', u'123.456.7.9'
-    iqn = u'iqn.1992-04.com.emc:600009700bca30c01e3e012e00000001,t,0x0001'
-    iqn2 = u'iqn.1992-04.com.emc:600009700bca30c01e3e012e00000002,t,0x0001'
+    wwnn2 = '223456789012346'
+    initiator = 'iqn.1993-08.org.debian:01:222'
+    iscsi_dir = 'SE-4E'
+    iscsi_port = '1'
+    ip, ip2 = '123.456.7.8', '123.456.7.9'
+    iqn = 'iqn.1992-04.com.emc:600009700bca30c01e3e012e00000001'
+    iqn2 = 'iqn.1992-04.com.emc:600009700bca30c01e3e012e00000002'
     connector = {'ip': ip,
                  'initiator': initiator,
                  'wwpns': [wwpn1, wwpn2],
@@ -111,6 +117,7 @@ class PowerMaxData(object):
     end_point_map = {connector['wwpns'][0]: [wwnn1],
                      connector['wwpns'][1]: [wwnn1]}
     target_wwns = [wwnn1]
+    target_wwns_multi = [wwnn1, wwnn2]
     zoning_mappings = {
         'array': u'000197800123',
         'init_targ_map': end_point_map,
@@ -132,16 +139,22 @@ class PowerMaxData(object):
                       }
         device_map[fabric_name] = fabric_map
 
+    iscsi_dir_port = '%(dir)s:%(port)s' % {'dir': iscsi_dir,
+                                           'port': iscsi_port}
+    iscsi_dir_virtual_port = '%(dir)s:%(port)s' % {'dir': iscsi_dir,
+                                                   'port': '000'}
     iscsi_device_info = {'maskingview': masking_view_name_i,
                          'ip_and_iqn': [{'ip': ip,
-                                         'iqn': initiator}],
+                                         'iqn': initiator,
+                                         'physical_port': iscsi_dir_port}],
                          'is_multipath': True,
                          'array': array,
                          'controller': {'host': '10.00.00.00'},
                          'hostlunid': 3,
                          'device_id': device_id}
     iscsi_device_info_metro = deepcopy(iscsi_device_info)
-    iscsi_device_info_metro['metro_ip_and_iqn'] = [{'ip': ip2, 'iqn': iqn2}]
+    iscsi_device_info_metro['metro_ip_and_iqn'] = [{
+        'ip': ip2, 'iqn': iqn2, 'physical_port': iscsi_dir_port}]
     iscsi_device_info_metro['metro_hostlunid'] = 2
 
     fc_device_info = {'maskingview': masking_view_name_f,
@@ -149,6 +162,11 @@ class PowerMaxData(object):
                       'controller': {'host': '10.00.00.00'},
                       'hostlunid': 3}
 
+    director_port_keys_empty = {'symmetrixPortKey': []}
+    director_port_keys_multiple = {'symmetrixPortKey': [
+        {'directorId': 'SE-1E', 'portId': '1'},
+        {'directorId': 'SE-1E', 'portId': '2'}]}
+
     # snapshot info
     snapshot_id = '390eeb4d-0f56-4a02-ba14-167167967014'
     snapshot_display_id = 'my_snap'
@@ -212,6 +230,13 @@ class PowerMaxData(object):
         volume_type=test_volume_type, host=fake_host,
         replication_driver_data=six.text_type(provider_location3))
 
+    test_rep_volume = fake_volume.fake_volume_obj(
+        context=ctx, name='vol1', size=2, provider_auth=None,
+        provider_location=six.text_type(provider_location),
+        volume_type=test_volume_type, host=fake_host,
+        replication_driver_data=six.text_type(provider_location3),
+        replication_status=fields.ReplicationStatus.ENABLED)
+
     test_attached_volume = fake_volume.fake_volume_obj(
         id='4732de9b-98a4-4b6d-ae4b-3cafb3d34220', context=ctx, name='vol1',
         size=0, provider_auth=None, attach_status='attached',
@@ -443,6 +468,10 @@ class PowerMaxData(object):
     rep_extra_specs_rep_config = deepcopy(rep_extra_specs6)
     rep_extra_specs_rep_config[utils.REP_CONFIG] = rep_config_sync
 
+    rep_extra_specs_rep_config_metro = deepcopy(rep_extra_specs6)
+    rep_extra_specs_rep_config_metro[utils.REP_CONFIG] = rep_config_metro
+    rep_extra_specs_rep_config_metro[utils.REP_MODE] = utils.REP_METRO
+
     extra_specs_tags = deepcopy(extra_specs)
     extra_specs_tags.update({utils.STORAGE_GROUP_TAGS: sg_tags})
 
@@ -854,7 +883,7 @@ class PowerMaxData(object):
                             {'snapshotHeader': {
                                 'snapshotName': 'temp-1',
                                 'device': device_id,
-                                'generation': '0'},
+                                'snapid': snap_id},
                                 'lnkSnapshotGenInfo': [
                                     {'targetDevice': device_id2,
                                      'state': 'Copied'}]}]},
@@ -862,7 +891,7 @@ class PowerMaxData(object):
                             'snapshotName': 'temp-1',
                             'targetDevice': device_id2,
                             'sourceDevice': device_id,
-                            'generation': '0',
+                            'snapid': snap_id_2,
                             'state': 'Copied'}}],
                     'snapVXSrc': 'true',
                     'snapVXTgt': 'true'},
@@ -890,14 +919,15 @@ class PowerMaxData(object):
     # replication
     volume_snap_vx = {'snapshotLnks': [],
                       'snapshotSrcs': [
-                          {'generation': 0,
+                          {'snap_id': snap_id,
                            'linkedDevices': [
                                {'targetDevice': device_id2,
                                 'percentageCopied': 100,
                                 'state': 'Copied',
                                 'copy': True,
                                 'defined': True,
-                                'linked': True}],
+                                'linked': True,
+                                'snap_id': snap_id}],
                            'snapshotName': test_snapshot_snap_name,
                            'state': 'Established'}]}
     capabilities = {'symmetrixCapability': [{'rdfCapable': True,
@@ -988,7 +1018,7 @@ class PowerMaxData(object):
                  {'symmetrixId': array_herc,
                   'model': 'PowerMax 2000',
                   'ucode': '5978.1091.1092'}]
-    version_details = {'version': 'V9.1.0.1054'}
+    version_details = {'version': 'V9.2.0.0'}
 
     headroom = {'headroom': [{'headroomCapacity': 20348.29}]}
 
@@ -1052,7 +1082,8 @@ class PowerMaxData(object):
                         {'snapshotHeader': {
                             'timestamp': 1512763278000, 'expired': False,
                             'secured': False, 'snapshotName': 'testSnap1',
-                            'device': '00001', 'generation': 0, 'timeToLive': 0
+                            'device': '00001', 'snapid': snap_id,
+                            'timeToLive': 0, 'generation': 0
                         }}]}]}}]
 
     priv_vol_func_response_multi = [
@@ -1078,7 +1109,8 @@ class PowerMaxData(object):
                         {'snapshotHeader': {
                             'timestamp': 1512763278000, 'expired': False,
                             'secured': False, 'snapshotName': 'testSnap1',
-                            'device': '00001', 'generation': 0, 'timeToLive': 0
+                            'device': '00001', 'snapid': snap_id,
+                            'timeToLive': 0, 'generation': 0
                         }}]}]}},
         {'volumeHeader': {
             'private': False, 'capGB': 200.0, 'capMB': 204800.0,
@@ -1102,7 +1134,8 @@ class PowerMaxData(object):
                         {'snapshotHeader': {
                             'timestamp': 1512763278000, 'expired': False,
                             'secured': False, 'snapshotName': 'testSnap2',
-                            'device': '00002', 'generation': 0, 'timeToLive': 0
+                            'device': '00002', 'snapid': snap_id,
+                            'timeToLive': 0, 'generation': 0
                         }}]}]}},
         {'volumeHeader': {
             'private': False, 'capGB': 300.0, 'capMB': 307200.0,
@@ -1126,7 +1159,8 @@ class PowerMaxData(object):
                         {'snapshotHeader': {
                             'timestamp': 1512763278000, 'expired': False,
                             'secured': False, 'snapshotName': 'testSnap3',
-                            'device': '00003', 'generation': 0, 'timeToLive': 0
+                            'device': '00003', 'snapid': snap_id,
+                            'timeToLive': 0, 'generation': 0
                         }}]}]}},
         {'volumeHeader': {
             'private': False, 'capGB': 400.0, 'capMB': 409600.0,
@@ -1150,7 +1184,8 @@ class PowerMaxData(object):
                         {'snapshotHeader': {
                             'timestamp': 1512763278000, 'expired': False,
                             'secured': False, 'snapshotName': 'testSnap4',
-                            'device': '00004', 'generation': 0, 'timeToLive': 0
+                            'device': '00004', 'snapid': snap_id,
+                            'timeToLive': 0, 'generation': 0
                         }}]}]}}]
 
     priv_vol_func_response_multi_invalid = [
@@ -1274,7 +1309,7 @@ class PowerMaxData(object):
 
     data_dict = {volume_id: volume_info_dict}
     platform = 'Linux-4.4.0-104-generic-x86_64-with-Ubuntu-16.04-xenial'
-    unisphere_version = u'V9.1.0.17'
+    unisphere_version = u'V9.2.0.0'
     unisphere_version_90 = "V9.0.0.1"
     openstack_release = '12.0.0.0b3.dev401'
     openstack_version = '12.0.0'
@@ -1324,19 +1359,21 @@ class PowerMaxData(object):
         'RestServerPort': '8443',
         'RestUserName': 'test',
         'RestPassword': 'test',
-        'SSLVerify': '/path/to/cert'},
+        'SSLVerify': '/path/to/cert',
+        'SerialNumber': array},
         {'RestServerIp': '10.10.10.12',
          'RestServerPort': '8443',
          'RestUserName': 'test',
          'RestPassword': 'test',
-         'SSLVerify': 'True'}]
+         'SSLVerify': 'True',
+         'SerialNumber': array}]
 
     snapshot_src_details = {'snapshotSrcs': [{
         'snapshotName': 'temp-000AA-snapshot_for_clone',
-        'generation': 0, 'state': 'Established', 'expired': False,
+        'snap_id': snap_id, 'state': 'Established', 'expired': False,
         'linkedDevices': [{'targetDevice': device_id2, 'state': 'Copied',
                            'copy': True}]},
-        {'snapshotName': 'temp-000AA-snapshot_for_clone', 'generation': 1,
+        {'snapshotName': 'temp-000AA-snapshot_for_clone', 'snap_id': snap_id_2,
          'state': 'Established', 'expired': False,
          'linkedDevices': [{'targetDevice': device_id3, 'state': 'Copied',
                             'copy': True}]}],
@@ -1347,24 +1384,24 @@ class PowerMaxData(object):
 
     snap_tgt_vol_details = {"timeFinderInfo": {"snapVXSession": [{
         "tgtSrcSnapshotGenInfo": {
-            "generation": 6, "expired": True,
+            "snapid": snap_id, "expired": True,
             "snapshotName": "temp-000AA-snapshot_for_clone"}}]}}
 
     snap_tgt_session = {
-        'generation': 0, 'expired': False, 'copy_mode': False,
+        'snapid': snap_id, 'expired': False, 'copy_mode': False,
         'snap_name': 'temp-000AA-snapshot_for_clone', 'state': 'Copied',
         'source_vol_id': device_id, 'target_vol_id': device_id2}
 
     snap_tgt_session_cm_enabled = {
-        'generation': 0, 'expired': False, 'copy_mode': True,
+        'snapid': snap_id, 'expired': False, 'copy_mode': True,
         'snap_name': 'temp-000AA-snapshot_for_clone', 'state': 'Copied',
         'source_vol_id': device_id, 'target_vol_id': device_id2}
 
     snap_src_sessions = [
-        {'generation': 0, 'expired': False, 'copy_mode': False,
+        {'snapid': snap_id, 'expired': False, 'copy_mode': False,
          'snap_name': 'temp-000AA-snapshot_for_clone', 'state': 'Copied',
          'source_vol_id': device_id, 'target_vol_id': device_id3},
-        {'generation': 1, 'expired': False, 'copy_mode': False,
+        {'snapid': snap_id_2, 'expired': False, 'copy_mode': False,
          'snap_name': 'temp-000AA-snapshot_for_clone', 'state': 'Copied',
          'source_vol_id': device_id, 'target_vol_id': device_id4}]
 
@@ -1430,11 +1467,10 @@ class PowerMaxData(object):
 
     snap_device_label = ('%(dev)s:%(label)s' % {'dev': device_id,
                                                 'label': managed_snap_id})
-
     priv_snap_response = {
         'deviceName': snap_device_label, 'snapshotLnks': [],
         'snapshotSrcs': [
-            {'generation': 0,
+            {'snap_id': snap_id,
              'linkedDevices': [
                  {'targetDevice': device_id2, 'percentageCopied': 100,
                   'state': 'Copied', 'copy': True, 'defined': True,
@@ -1442,9 +1478,6 @@ class PowerMaxData(object):
              'snapshotName': test_snapshot_snap_name,
              'state': 'Established'}]}
 
-    priv_snap_response_no_label = deepcopy(priv_snap_response)
-    priv_snap_response_no_label.update({'deviceName': device_id})
-
     volume_metadata = {
         'DeviceID': device_id, 'ArrayID': array, 'ArrayModel': array_model}
 
@@ -1478,7 +1511,7 @@ class PowerMaxData(object):
             'expandStorageGroupParam': {
                 'addVolumeParam': {
                     'emulation': 'FBA',
-                    'create_new_volumes': 'False',
+                    'create_new_volumes': 'True',
                     'volumeAttributes': [
                         {'num_of_vols': 1,
                          'volumeIdentifier': {
@@ -1527,6 +1560,77 @@ class PowerMaxData(object):
                       'Emulation': 'FBA',
                       'Configuration': 'TDEV',
                       'CompressionDisabled': False}})
+
+    vol_create_desc1 = 'Populating Storage Group(s) with volumes : [00001]'
+    vol_create_desc2 = ('Refresh [Storage Group [OS-SG] '
+                        'on Symmetrix [000197800123]] ')
+    vol_create_task = [{'execution_order': 1,
+                        'description': vol_create_desc1},
+                       {'execution_order': 2,
+                        'description': vol_create_desc2}]
+
+    # performance
+    f_date_a = 1593432600000
+    f_date_b = 1594136400000
+    l_date = 1594730100000
+    perf_pb_metric = 'PercentBusy'
+    perf_df_avg = 'Average'
+    perf_port_groups = ['port_group_a', 'port_group_b', 'port_group_c']
+    perf_ports = ['SE-1E:1', 'SE-1E:2', 'SE-1E:3']
+
+    performance_config = {
+        'load_balance': True, 'load_balance_rt': True,
+        'perf_registered': True, 'rt_registered': True,
+        'collection_interval': 5, 'data_format': 'Average',
+        'look_back': 60, 'look_back_rt': 10,
+        'port_group_metric': 'PercentBusy', 'port_metric': 'PercentBusy'}
+
+    array_registration = {"registrationDetailsInfo": [
+        {"symmetrixId": array, "realtime": True, "message": "Success",
+         "collectionintervalmins": 5, "diagnostic": True}]}
+
+    array_keys = {"arrayInfo": [
+        {"symmetrixId": array,
+         "firstAvailableDate": f_date_a,
+         "lastAvailableDate": l_date},
+        {"symmetrixId": array_herc,
+         "firstAvailableDate": f_date_a,
+         "lastAvailableDate": l_date},
+        {"symmetrixId": remote_array,
+         "firstAvailableDate": f_date_b,
+         "lastAvailableDate": l_date}]}
+
+    dummy_performance_data = {
+        "expirationTime": 1594731525645,
+        "count": 10,
+        "maxPageSize": 1000,
+        "id": "3b757302-6e4a-4dbe-887d-e42aed7f5944_0",
+        "resultList": {
+            "result": [
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593432600000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593432900000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593433200000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593433500000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593433800000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593434100000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593434400000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593434700000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593435000000},
+                {"PercentBusy": random.uniform(0.0, 100.0),
+                 "timestamp": 1593435300000}],
+            "from": 1,
+            "to": 10
+        }
+    }
     staging_sg = 'STG-myhostB-4732de9b-98a4-4b6d-ae4b-3cafb3d34220-SG'
     staging_mv1 = 'STG-myhostA-4732de9b-98a4-4b6d-ae4b-3cafb3d34220-MV'
     staging_mv2 = 'STG-myhostB-4732de9b-98a4-4b6d-ae4b-3cafb3d34220-MV'
@@ -1537,3 +1641,40 @@ class PowerMaxData(object):
     legacy_mvs = [legacy_mv1, legacy_mv2]
     legacy_not_shared_mv = 'OS-myhostA-SRP_1-Diamond-NONE-MV'
     legacy_not_shared_sg = 'OS-myhostA-SRP_1-Diamond-NONE-SG'
+    snapshot_metadata = {'SnapshotLabel': test_snapshot_snap_name,
+                         'SourceDeviceID': device_id,
+                         'SourceDeviceLabel': device_label,
+                         'SnapIdList': [snap_id]}
+
+    port_info = {
+        "symmetrixPort": {
+            "director_status": "Online",
+            "maskingview": [
+                "Test_MV",
+            ],
+            "port_status": "ON",
+            "symmetrixPortKey": {
+                "directorId": "FA-1D",
+                "portId": "4"
+            },
+            "portgroup": [
+                "Test_PG"
+            ]
+        }
+    }
+
+    port_info_off = deepcopy(port_info)
+    port_info_off.update({"symmetrixPort": {
+        "director_status": "Offline",
+        "port_status": "OFF"}})
+
+    port_info_no_status = deepcopy(port_info)
+    port_info_no_status.update({"symmetrixPort": {
+        "symmetrixPortKey": {
+            "directorId": "FA-1D",
+            "portId": "4"
+        }
+    }})
+
+    port_info_no_details = deepcopy(port_info)
+    port_info_no_details.pop("symmetrixPort")
