@@ -20,7 +20,7 @@ from unittest import mock
 
 from oslo_utils import units
 
-from cinder import test
+from cinder.tests.unit import test
 from cinder.volume.drivers.vmware import datastore as ds_sel
 from cinder.volume.drivers.vmware import exceptions as vmdk_exceptions
 
@@ -285,7 +285,7 @@ class DatastoreTest(test.TestCase):
             datastores, valid_host_refs=[host2, host3])
 
         self.assertEqual((host2, rp, ds3_props['summary']), ret)
-        self.assertItemsEqual([mock.call(mock.sentinel.ds1_mount_info2),
+        self.assertCountEqual([mock.call(mock.sentinel.ds1_mount_info2),
                                mock.call(mock.sentinel.ds1_mount_info3),
                                mock.call(mock.sentinel.ds2_mount_info2),
                                mock.call(mock.sentinel.ds2_mount_info3),
