@@ -22,7 +22,6 @@ from castellan.common import exception as castellan_exc
 from castellan.tests.unit.key_manager import mock_key_manager
 import ddt
 from oslo_utils import imageutils
-import six
 
 from cinder import context
 from cinder import exception
@@ -269,6 +268,33 @@ class CreateVolumeFlowTestCase(test.TestCase):
                               multiattach=None)
         self.assertEqual(bootable, result['volume_properties']['bootable'])
 
+    @mock.patch('cinder.db.volume_create')
+    @mock.patch('cinder.objects.Volume.get_by_id')
+    @ddt.unpack
+    def test_create_from_source_volid_encrypted(self,
+                                                volume_get_by_id,
+                                                volume_create):
+
+        volume_db = {'encryption_key_id': fakes.ENCRYPTION_KEY_ID}
+        volume_obj = fake_volume.fake_volume_obj(self.ctxt, **volume_db)
+        volume_get_by_id.return_value = volume_obj
+        volume_create.return_value = {'id': fakes.VOLUME2_ID}
+        task = create_volume.EntryCreateTask()
+
+        result = task.execute(self.ctxt,
+                              optional_args=None,
+                              source_volid=volume_obj.id,
+                              snapshot_id=None,
+                              availability_zones=['nova'],
+                              size=1,
+                              encryption_key_id=volume_obj.encryption_key_id,
+                              description='123',
+                              name='123',
+                              multiattach=None)
+        self.assertEqual(
+            fakes.ENCRYPTION_KEY_ID,
+            result['volume_properties']['encryption_key_id'])
+
     @ddt.data(('enabled', {'replication_enabled': '<is> True'}),
               ('disabled', {'replication_enabled': '<is> False'}),
               ('disabled', {}))
@@ -459,7 +485,7 @@ class CreateVolumeFlowTestCase(test.TestCase):
             fake_get_qos,
             fake_is_encrypted):
         fake_image_service = fake_image.FakeImageService()
-        image_id = six.text_type(uuid.uuid4())
+        image_id = str(uuid.uuid4())
         image_meta = {}
         image_meta['id'] = image_id
         image_meta['status'] = 'active'
@@ -513,7 +539,7 @@ class CreateVolumeFlowTestCase(test.TestCase):
     def test__extract_availability_zones_az_not_specified(self, type_azs,
                                                           self_azs, expected):
         fake_image_service = fake_image.FakeImageService()
-        image_id = six.text_type(uuid.uuid4())
+        image_id = str(uuid.uuid4())
         image_meta = {}
         image_meta['id'] = image_id
         image_meta['status'] = 'active'
@@ -539,7 +565,7 @@ class CreateVolumeFlowTestCase(test.TestCase):
     def test__extract_availability_zones_az_not_in_type_azs(self):
         self.override_config('allow_availability_zone_fallback', False)
         fake_image_service = fake_image.FakeImageService()
-        image_id = six.text_type(uuid.uuid4())
+        image_id = str(uuid.uuid4())
         image_meta = {}
         image_meta['id'] = image_id
         image_meta['status'] = 'active'
@@ -1017,6 +1043,31 @@ class CreateVolumeFlowManagerTestCase(test.TestCase):
         super(CreateVolumeFlowManagerTestCase, self).setUp()
         self.ctxt = context.get_admin_context()
 
+    @mock.patch('cinder.volume.flows.manager.create_volume.'
+                'CreateVolumeFromSpecTask.'
+                '_cleanup_cg_in_volume')
+    @mock.patch('cinder.volume.flows.manager.create_volume.'
+                'CreateVolumeFromSpecTask.'
+                '_rekey_volume')
+    @mock.patch('cinder.objects.Volume.update')
+    @mock.patch('cinder.objects.Volume.get_by_id')
+    def test_create_from_source_volume_encrypted_update_volume(
+            self, volume_get_by_id, vol_update, rekey_vol, cleanup_cg):
+        fake_db = mock.MagicMock()
+        fake_driver = mock.MagicMock()
+        fake_volume_manager = mock.MagicMock()
+        fake_manager = create_volume_manager.CreateVolumeFromSpecTask(
+            fake_volume_manager, fake_db, fake_driver)
+        volume_db = {'encryption_key_id': fakes.ENCRYPTION_KEY_ID}
+        volume_obj = fake_volume.fake_volume_obj(self.ctxt, **volume_db)
+        volume_get_by_id.return_value = volume_obj
+        source_volume_id = fakes.VOLUME2_ID
+
+        fake_manager._create_from_source_volume(
+            self.ctxt, volume_obj, source_volume_id)
+        # Check if volume object is updated.
+        self.assertTrue(vol_update.called)
+
     @mock.patch('cinder.volume.flows.manager.create_volume.'
                 'CreateVolumeFromSpecTask.'
                 '_cleanup_cg_in_volume')
@@ -1255,68 +1306,12 @@ class CreateVolumeFlowManagerTestCase(test.TestCase):
             exception=err)
 
 
-@ddt.ddt(testNameFormat=ddt.TestNameFormat.INDEX_ONLY)
 class CreateVolumeFlowManagerGlanceCinderBackendCase(test.TestCase):
 
     def setUp(self):
         super(CreateVolumeFlowManagerGlanceCinderBackendCase, self).setUp()
         self.ctxt = context.get_admin_context()
 
-    # data for test__extract_cinder_ids
-    #   legacy glance cinder URI:    cinder://<volume-id>
-    #   new-style glance cinder URI: cinder://<glance-store>/<volume_id>
-    LEGACY_VOL2 = 'cinder://%s' % fakes.VOLUME2_ID
-    NEW_VOL3 = 'cinder://glance-store-name/%s' % fakes.VOLUME3_ID
-    # these *may* be illegal names in glance, but check anyway
-    NEW_VOL4 = 'cinder://glance/store/name/%s' % fakes.VOLUME4_ID
-    NEW_VOL5 = 'cinder://glance:store:name/%s' % fakes.VOLUME5_ID
-    NEW_VOL6 = 'cinder://glance:store,name/%s' % fakes.VOLUME6_ID
-    NOT_CINDER1 = 'rbd://%s' % fakes.UUID1
-    NOT_CINDER2 = 'http://%s' % fakes.UUID2
-    NOGOOD3 = 'cinder://glance:store,name/%s/garbage' % fakes.UUID3
-    NOGOOD4 = 'cinder://glance:store,name/%s-garbage' % fakes.UUID4
-    NOGOOD5 = fakes.UUID5
-    NOGOOD6 = 'cinder://store-name/12345678'
-    NOGOOD7 = 'cinder://'
-    NOGOOD8 = 'some-random-crap'
-    NOGOOD9 = None
-
-    TEST_CASE_DATA = (
-        # the format of these is: (input, expected output)
-        ([LEGACY_VOL2], [fakes.VOLUME2_ID]),
-        ([NEW_VOL3], [fakes.VOLUME3_ID]),
-        ([NEW_VOL4], [fakes.VOLUME4_ID]),
-        ([NEW_VOL5], [fakes.VOLUME5_ID]),
-        ([NEW_VOL6], [fakes.VOLUME6_ID]),
-        ([], []),
-        ([''], []),
-        ([NOT_CINDER1], []),
-        ([NOT_CINDER2], []),
-        ([NOGOOD3], []),
-        ([NOGOOD4], []),
-        ([NOGOOD5], []),
-        ([NOGOOD6], []),
-        ([NOGOOD7], []),
-        ([NOGOOD8], []),
-        ([NOGOOD9], []),
-        ([NOT_CINDER1, NOGOOD4], []),
-        # mix of URIs should only get the cinder IDs
-        ([LEGACY_VOL2, NOT_CINDER1, NEW_VOL3, NOT_CINDER2],
-         [fakes.VOLUME2_ID, fakes.VOLUME3_ID]),
-        # a bad cinder URI early in the list shouldn't prevent us from
-        # processing a good one later in the list
-        ([NOGOOD6, NEW_VOL3, NOGOOD7, LEGACY_VOL2],
-         [fakes.VOLUME3_ID, fakes.VOLUME2_ID]),
-    )
-
-    @ddt.data(*TEST_CASE_DATA)
-    @ddt.unpack
-    def test__extract_cinder_ids(self, url_list, id_list):
-        """Test utility function that gets IDs from Glance location URIs"""
-        klass = create_volume_manager.CreateVolumeFromSpecTask
-        actual = klass._extract_cinder_ids(url_list)
-        self.assertEqual(id_list, actual)
-
     @mock.patch('cinder.volume.flows.manager.create_volume.'
                 'CreateVolumeFromSpecTask.'
                 '_cleanup_cg_in_volume')
@@ -1378,10 +1373,6 @@ class CreateVolumeFlowManagerGlanceCinderBackendCase(test.TestCase):
             self.assertFalse(fake_driver.create_cloned_volume.called)
         mock_cleanup_cg.assert_called_once_with(volume)
 
-    LEGACY_URI = 'cinder://%s' % fakes.VOLUME_ID
-    MULTISTORE_URI = 'cinder://fake-store/%s' % fakes.VOLUME_ID
-
-    @ddt.data(LEGACY_URI, MULTISTORE_URI)
     @mock.patch('cinder.volume.flows.manager.create_volume.'
                 'CreateVolumeFromSpecTask.'
                 '_cleanup_cg_in_volume')
@@ -1390,8 +1381,7 @@ class CreateVolumeFlowManagerGlanceCinderBackendCase(test.TestCase):
                 'CreateVolumeFromSpecTask.'
                 '_handle_bootable_volume_glance_meta')
     @mock.patch('cinder.image.image_utils.qemu_img_info')
-    def test_create_from_image_volume_ignore_size(self, location_uri,
-                                                  mock_qemu_info,
+    def test_create_from_image_volume_ignore_size(self, mock_qemu_info,
                                                   handle_bootable,
                                                   mock_fetch_img,
                                                   mock_cleanup_cg,
@@ -1418,7 +1408,7 @@ class CreateVolumeFlowManagerGlanceCinderBackendCase(test.TestCase):
         # will fail because of free space being too low.
         image_info.virtual_size = '1073741824000000000000'
         mock_qemu_info.return_value = image_info
-        url = location_uri
+        url = 'cinder://%s' % image_volume['id']
         image_location = None
         if location:
             image_location = (url, [{'url': url, 'metadata': {}}])
