@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2018 Dell Inc. or its subsidiaries.
+# Copyright (c) 2020 Dell Inc. or its subsidiaries.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,12 +15,13 @@
 
 from copy import deepcopy
 import datetime
-import hashlib
 import re
 
 from oslo_log import log as logging
+from oslo_utils.secretutils import md5
 from oslo_utils import strutils
 from oslo_utils import units
+import packaging.version
 import six
 
 from cinder import exception
@@ -42,6 +43,7 @@ MAX_SRP_LENGTH = 16
 TRUNCATE_5 = 5
 TRUNCATE_27 = 27
 UCODE_5978_ELMSR = 221
+UCODE_5978_HICKORY = 660
 UCODE_5978 = 5978
 UPPER_HOST_CHARS = 16
 UPPER_PORT_GROUP_CHARS = 12
@@ -78,12 +80,16 @@ RDF_FAILEDOVER_STATE = 'failed over'
 RDF_ACTIVE = 'active'
 RDF_ACTIVEACTIVE = 'activeactive'
 RDF_ACTIVEBIAS = 'activebias'
+RDF_PARTITIONED_STATE = 'partitioned'
+RDF_TRANSIDLE_STATE = 'transidle'
+RDF_PAIR_STATE = 'rdfpairState'
 RDF_VALID_STATES_SYNC = [RDF_SYNC_STATE, RDF_SUSPENDED_STATE,
                          RDF_SYNCINPROG_STATE]
 RDF_VALID_STATES_ASYNC = [RDF_CONSISTENT_STATE, RDF_SUSPENDED_STATE,
                           RDF_SYNCINPROG_STATE]
 RDF_VALID_STATES_METRO = [RDF_ACTIVEBIAS, RDF_ACTIVEACTIVE,
                           RDF_SUSPENDED_STATE, RDF_SYNCINPROG_STATE]
+RDF_PARTITIONED_STATES = [RDF_PARTITIONED_STATE, RDF_TRANSIDLE_STATE]
 RDF_CONS_EXEMPT = 'exempt'
 RDF_ALLOW_METRO_DELETE = 'allow_delete_metro'
 RDF_GROUP_NO = 'rdf_group_number'
@@ -100,6 +106,7 @@ USED_HOST_NAME = "used_host_name"
 RDF_SYNCED_STATES = [RDF_SYNC_STATE, RDF_CONSISTENT_STATE,
                      RDF_ACTIVEACTIVE, RDF_ACTIVEBIAS]
 FORCE_VOL_EDIT = 'force_vol_edit'
+PMAX_FAILOVER_START_ARRAY_PROMOTION = 'pmax_failover_start_array_promotion'
 
 # Multiattach constants
 IS_MULTIATTACH = 'multiattach'
@@ -115,12 +122,7 @@ VMAX_SERVER_IP = 'san_ip'
 VMAX_USER_NAME = 'san_login'
 VMAX_PASSWORD = 'san_password'
 U4P_SERVER_PORT = 'san_api_port'
-VMAX_ARRAY = 'vmax_array'
 VMAX_WORKLOAD = 'vmax_workload'
-VMAX_SRP = 'vmax_srp'
-VMAX_SERVICE_LEVEL = 'vmax_service_level'
-VMAX_PORT_GROUPS = 'vmax_port_groups'
-VMAX_SNAPVX_UNLINK_LIMIT = 'vmax_snapvx_unlink_limit'
 U4P_FAILOVER_TIMEOUT = 'u4p_failover_timeout'
 U4P_FAILOVER_RETRIES = 'u4p_failover_retries'
 U4P_FAILOVER_BACKOFF_FACTOR = 'u4p_failover_backoff_factor'
@@ -152,6 +154,69 @@ PMAX_SLS = ['Diamond', 'Platinum', 'Gold', 'Silver', 'Bronze', 'Optimized',
             'None', 'NONE']
 PMAX_WLS = ['NONE', 'None']
 
+# Performance
+# Metrics
+PG_METRICS = [
+    'AvgIOSize', 'IOs', 'MBRead', 'MBWritten', 'MBs', 'PercentBusy',
+    'Reads', 'Writes']
+PORT_METRICS = [
+    'AvgIOSize', 'IOs', 'MBRead', 'MBWritten', 'MBs', 'MaxSpeedGBs',
+    'PercentBusy', 'ReadResponseTime', 'Reads', 'ResponseTime', 'SpeedGBs',
+    'WriteResponseTime', 'Writes']
+PORT_RT_METRICS = [
+    'AvgIOSize', 'IOs', 'MBRead', 'MBWritten', 'MBs', 'PercentBusy', 'Reads',
+    'ResponseTime', 'Writes']
+
+# Cinder config options
+LOAD_BALANCE = 'load_balance'
+LOAD_BALANCE_RT = 'load_balance_real_time'
+PERF_DATA_FORMAT = 'load_data_format'
+LOAD_LOOKBACK = 'load_look_back'
+LOAD_LOOKBACK_RT = 'load_look_back_real_time'
+PORT_GROUP_LOAD_METRIC = 'port_group_load_metric'
+PORT_LOAD_METRIC = 'port_load_metric'
+
+# One minute in milliseconds
+ONE_MINUTE = 60000
+# Default look back windows in minutes
+DEFAULT_DIAG_WINDOw = 60
+DEFAULT_RT_WINDOW = 1
+
+# REST API keys
+PERFORMANCE = 'performance'
+REG_DETAILS = 'registrationdetails'
+REG_DETAILS_INFO = 'registrationDetailsInfo'
+COLLECTION_INT = 'collectionintervalmins'
+DIAGNOSTIC = 'diagnostic'
+REAL_TIME = 'realtime'
+RESULT_LIST = 'resultList'
+RESULT = 'result'
+KEYS = 'keys'
+METRICS = 'metrics'
+CAT = 'category'
+F_DATE = 'firstAvailableDate'
+S_DATE = 'startDate'
+L_DATE = 'lastAvailableDate'
+E_DATE = 'endDate'
+SYMM_ID = 'symmetrixId'
+ARRAY_PERF = 'Array'
+ARRAY_INFO = 'arrayInfo'
+PORT_GROUP = 'PortGroup'
+PORT_GROUP_ID = 'portGroupId'
+FE_PORT_RT = 'FEPORT'
+FE_PORT_DIAG = 'FEPort'
+DATA_FORMAT = 'dataFormat'
+INST_ID = 'instanceId'
+DIR_ID = 'directorId'
+PORT_ID = 'portId'
+
+# Revert snapshot exception
+REVERT_SS_EXC = 'Link must be fully copied for this operation to proceed'
+
+# extra specs
+IS_TRUE = ['<is> True', 'True', 'true', True]
+IS_FALSE = ['<is> False', 'False', 'false', False]
+
 
 class PowerMaxUtils(object):
     """Utility class for Rest based PowerMax volume drivers.
@@ -370,7 +435,7 @@ class PowerMaxUtils(object):
         :returns: uuid
         """
         input_str = input_str.lower()
-        m = hashlib.md5()
+        m = md5(usedforsecurity=False)
         m.update(input_str.encode('utf-8'))
         return m.hexdigest()
 
@@ -444,7 +509,7 @@ class PowerMaxUtils(object):
         compression_disabled = False
 
         if extra_specs.get(DISABLECOMPRESSION, False):
-            if strutils.bool_from_string(extra_specs.get(DISABLECOMPRESSION)):
+            if extra_specs.get(DISABLECOMPRESSION) in IS_TRUE:
                 compression_disabled = True
         else:
             if extra_specs.get(SLO):
@@ -733,6 +798,35 @@ class PowerMaxUtils(object):
             pools.append(new_pool)
         return pools
 
+    @staticmethod
+    def add_promotion_pools(pools, primary_array):
+        """Add duplicate pools with primary SID for operations during promotion
+
+        :param pools: the pool list
+        :param primary_array: the original primary array.
+        :returns: pools - the updated pool list
+        """
+        i_pools = deepcopy(pools)
+        for pool in i_pools:
+            # pool name
+            pool_name = pool['pool_name']
+            split_name = pool_name.split('+')
+            array_pos = 3 if len(split_name) == 4 else 2
+            array_sid = split_name[array_pos]
+            updated_pool_name = re.sub(array_sid, primary_array, pool_name)
+
+            # location info
+            loc = pool['location_info']
+            split_loc = loc.split('#')
+            split_loc[0] = primary_array  # Replace the array SID
+            updated_loc = '#'.join(split_loc)
+
+            new_pool = deepcopy(pool)
+            new_pool['pool_name'] = updated_pool_name
+            new_pool['location_info'] = updated_loc
+            pools.append(new_pool)
+        return pools
+
     def check_replication_matched(self, volume, extra_specs):
         """Check volume type and group type.
 
@@ -1143,6 +1237,14 @@ class PowerMaxUtils(object):
                              'are defined in cinder.conf, backend_id %s is '
                              'defined more than once.') % backend_id)
                     raise exception.InvalidConfigurationValue(msg)
+                elif backend_id == PMAX_FAILOVER_START_ARRAY_PROMOTION:
+                    msg = (_('Invalid Backend ID found. Defining a '
+                             'replication device with a Backend ID of %s is '
+                             'currently not supported. Please update '
+                             'the Backend ID of the related replication '
+                             'device in cinder.conf to use valid '
+                             'Backend ID value.') % backend_id)
+                    raise exception.InvalidConfigurationValue(msg)
             else:
                 msg = _('Backend IDs must be assigned for each rep_device '
                         'when multiple replication devices are defined in '
@@ -1683,6 +1785,9 @@ class PowerMaxUtils(object):
         :param storage_group_name: the storage group name -- str
         :returns: updated payload -- dict
         """
+        create_new_vol = {"create_new_volumes": "True"}
+        payload["editStorageGroupActionParam"]["expandStorageGroupParam"][
+            "addVolumeParam"].update(create_new_vol)
         remote_dict = {"remoteSymmSGInfoParam": {
             "remote_symmetrix_1_id": remote_array_id,
             "remote_symmetrix_1_sgs": [storage_group_name],
@@ -1726,11 +1831,12 @@ class PowerMaxUtils(object):
                     return False
 
     @staticmethod
-    def get_rep_config(backend_id, rep_configs):
+    def get_rep_config(backend_id, rep_configs, promotion_vol_stats=False):
         """Get rep_config for given backend_id.
 
         :param backend_id: rep config search key -- str
         :param rep_configs: backend rep_configs -- list
+        :param promotion_vol_stats: get rep config for vol stats -- bool
         :returns: rep_config -- dict
         """
         if len(rep_configs) == 1:
@@ -1741,20 +1847,25 @@ class PowerMaxUtils(object):
                 if rep_config[BACKEND_ID] == backend_id:
                     rep_device = rep_config
             if rep_device is None:
-                msg = (_('Could not find a replication_device with a '
-                         'backend_id of "%s" in cinder.conf. Please confirm '
-                         'that the replication_device_backend_id extra spec '
-                         'for this volume type matches the backend_id of the '
-                         'intended replication_device in '
-                         'cinder.conf.') % backend_id)
-                if BACKEND_ID_LEGACY_REP in msg:
-                    msg = (_('Could not find replication_device. Legacy '
-                             'replication_device key found, please ensure the '
-                             'backend_id for the legacy replication_device in '
-                             'cinder.conf has been changed to '
-                             '"%s".') % BACKEND_ID_LEGACY_REP)
-                LOG.error(msg)
-                raise exception.InvalidInput(msg)
+                if promotion_vol_stats:
+                    # Stat collection only need remote array and srp, any of
+                    # the available replication_devices can provide this.
+                    rep_device = rep_configs[0]
+                else:
+                    msg = (_('Could not find a replication_device with a '
+                             'backend_id of "%s" in cinder.conf. Please '
+                             'confirm that the replication_device_backend_id '
+                             'extra spec for this volume type matches the '
+                             'backend_id of the intended replication_device '
+                             'in cinder.conf.') % backend_id)
+                    if BACKEND_ID_LEGACY_REP in msg:
+                        msg = (_('Could not find replication_device. Legacy '
+                                 'replication_device key found, please ensure '
+                                 'the backend_id for the legacy '
+                                 'replication_device in cinder.conf has been '
+                                 'changed to "%s".') % BACKEND_ID_LEGACY_REP)
+                    LOG.error(msg)
+                    raise exception.InvalidInput(msg)
         return rep_device
 
     @staticmethod
@@ -1773,7 +1884,8 @@ class PowerMaxUtils(object):
         return list(replication_targets)
 
     def validate_failover_request(self, is_failed_over, failover_backend_id,
-                                  rep_configs):
+                                  rep_configs, primary_array, arrays_list,
+                                  is_promoted):
         """Validate failover_host request's parameters
 
         Validate that a failover_host operation can be performed with
@@ -1782,16 +1894,34 @@ class PowerMaxUtils(object):
         :param is_failed_over: current failover state
         :param failover_backend_id: backend_id given during failover request
         :param rep_configs: backend rep_configs -- list
+        :param primary_array: configured primary array SID -- string
+        :param arrays_list: list of U4P symmetrix IDs -- list
+        :param is_promoted: current promotion state -- bool
         :return: (bool, str) is valid, reason on invalid
         """
         is_valid = True
         msg = ""
         if is_failed_over:
-            if failover_backend_id != 'default':
+            valid_backend_ids = [
+                'default', PMAX_FAILOVER_START_ARRAY_PROMOTION]
+            if failover_backend_id not in valid_backend_ids:
                 is_valid = False
                 msg = _('Cannot failover, the backend is already in a failed '
                         'over state, if you meant to failback, please add '
                         '--backend_id default to the command.')
+            elif (failover_backend_id == 'default' and
+                  primary_array not in arrays_list):
+                is_valid = False
+                msg = _('Cannot failback, the configured primary array is '
+                        'not currently available to perform failback to. '
+                        'Please ensure array %s is visible in '
+                        'Unisphere.') % primary_array
+            elif is_promoted and failover_backend_id != 'default':
+                is_valid = False
+                msg = _('Failover promotion currently in progress, please '
+                        'finish the promotion process and issue a failover '
+                        'using the "default" backend_id to complete this '
+                        'process.')
         else:
             if failover_backend_id == 'default':
                 is_valid = False
@@ -1799,20 +1929,6 @@ class PowerMaxUtils(object):
                         'state. If you meant to failover, please either omit '
                         'the --backend_id parameter or use the --backend_id '
                         'parameter with a valid backend id.')
-            elif len(rep_configs) > 1:
-                if failover_backend_id is None:
-                    is_valid = False
-                    msg = _('Cannot failover, no backend_id provided while '
-                            'multiple replication devices are defined in '
-                            'cinder.conf, please provide a backend_id '
-                            'which will act as new primary array by '
-                            'appending --backend_id <id> to your command.')
-                else:
-                    rc = self.get_rep_config(failover_backend_id, rep_configs)
-                    if rc is None:
-                        is_valid = False
-                        msg = _('Can not find replication device with '
-                                'backend_id of %s') % failover_backend_id
         return is_valid, msg
 
     def validate_replication_group_config(self, rep_configs, extra_specs_list):
@@ -1933,8 +2049,9 @@ class PowerMaxUtils(object):
         :param minimum_version: minimum version allowed
         :returns: boolean
         """
-        from pkg_resources import parse_version
-        return parse_version(version) >= parse_version(minimum_version)
+        checking = packaging.version.parse(version)
+        minimum = packaging.version.parse(minimum_version)
+        return checking >= minimum
 
     @staticmethod
     def parse_specs_from_pool_name(pool_name):
@@ -1944,6 +2061,7 @@ class PowerMaxUtils(object):
         :returns: array_id, srp, service_level, workload -- str, str, str, str
         """
         array_id, srp, service_level, workload = str(), str(), str(), str()
+
         pool_details = pool_name.split('+')
         if len(pool_details) == 4:
             array_id = pool_details[3]
