@@ -14,10 +14,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import binascii
 import errno
 import os
+import tempfile
 import time
 
+from castellan import key_manager
 from os_brick.remotefs import remotefs as remotefs_brick
 from oslo_concurrency import processutils as putils
 from oslo_config import cfg
@@ -25,11 +28,13 @@ from oslo_log import log as logging
 from oslo_utils import units
 import six
 
+from cinder import context
 from cinder import coordination
 from cinder import exception
 from cinder.i18n import _
 from cinder.image import image_utils
 from cinder import interface
+from cinder import objects
 from cinder import utils
 from cinder.volume import configuration
 from cinder.volume.drivers import remotefs
@@ -56,8 +61,8 @@ nfs_opts = [
                default='$state_path/mnt',
                help='Base dir containing mount points for NFS shares.'),
     cfg.StrOpt('nfs_mount_options',
-               help='Mount options passed to the NFS client. See section '
-                    'of the NFS man page for details.'),
+               help='Mount options passed to the NFS client. See the NFS(5) '
+                    'man page for details.'),
     cfg.IntOpt('nfs_mount_attempts',
                default=3,
                help='The number of attempts to mount NFS shares before '
@@ -122,6 +127,8 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
                 self.configuration.max_over_subscription_ratio,
                 supports_auto=supports_auto_mosr))
 
+        self._supports_encryption = True
+
     @staticmethod
     def get_driver_options():
         return nfs_opts + remotefs.nas_opts
@@ -363,6 +370,12 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
 
     def extend_volume(self, volume, new_size):
         """Extend an existing volume to the new size."""
+        if self._is_volume_attached(volume):
+            # NOTE(kaisers): no attached extensions until #1870367 is fixed
+            msg = (_("Cannot extend volume %s while it is attached.")
+                   % volume['id'])
+            raise exception.ExtendVolumeError(msg)
+
         LOG.info('Extending volume %s.', volume.id)
         extend_by = int(new_size) - volume.size
         if not self._is_share_eligible(volume.provider_location,
@@ -372,9 +385,16 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
                                               % (volume.id, new_size))
         path = self.local_path(volume)
         LOG.info('Resizing file to %sG...', new_size)
+        file_format = None
+        admin_metadata = objects.Volume.get_by_id(
+            context.get_admin_context(), volume.id).admin_metadata
+        if admin_metadata and 'format' in admin_metadata:
+            file_format = admin_metadata['format']
         image_utils.resize_image(path, new_size,
-                                 run_as_root=self._execute_as_root)
-        if not self._is_file_size_equal(path, new_size):
+                                 run_as_root=self._execute_as_root,
+                                 file_format=file_format)
+        if file_format == 'qcow2' and not self._is_file_size_equal(
+                path, new_size):
             raise exception.ExtendVolumeError(
                 reason='Resizing image file failed.')
 
@@ -574,9 +594,12 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
     def delete_snapshot(self, snapshot):
         """Apply locking to the delete snapshot operation."""
 
+        self._check_snapshot_support()
         return self._delete_snapshot(snapshot)
 
-    def _copy_volume_from_snapshot(self, snapshot, volume, volume_size):
+    def _copy_volume_from_snapshot(self, snapshot, volume, volume_size,
+                                   src_encryption_key_id=None,
+                                   new_encryption_key_id=None):
         """Copy data from snapshot to destination volume.
 
         This is done with a qemu-img convert to raw/qcow2 from the snapshot
@@ -609,9 +632,46 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
         else:
             out_format = 'raw'
 
-        image_utils.convert_image(path_to_snap_img,
-                                  path_to_new_vol,
-                                  out_format,
-                                  run_as_root=self._execute_as_root)
+        if new_encryption_key_id is not None:
+            if src_encryption_key_id is None:
+                message = _("Can't create an encrypted volume %(format)s "
+                            "from an unencrypted source."
+                            ) % {'format': out_format}
+                LOG.error(message)
+                # TODO(enriquetaso): handle unencrypted snap->encrypted vol
+                raise exception.NfsException(message)
+            keymgr = key_manager.API(CONF)
+            new_key = keymgr.get(volume.obj_context, new_encryption_key_id)
+            new_passphrase = \
+                binascii.hexlify(new_key.get_encoded()).decode('utf-8')
+
+            # volume.obj_context is the owner of this request
+            src_key = keymgr.get(volume.obj_context, src_encryption_key_id)
+            src_passphrase = \
+                binascii.hexlify(src_key.get_encoded()).decode('utf-8')
+
+            tmp_dir = volume_utils.image_conversion_dir()
+            with tempfile.NamedTemporaryFile(prefix='luks_',
+                                             dir=tmp_dir) as src_pass_file:
+                with open(src_pass_file.name, 'w') as f:
+                    f.write(src_passphrase)
+
+                with tempfile.NamedTemporaryFile(prefix='luks_',
+                                                 dir=tmp_dir) as new_pass_file:
+                    with open(new_pass_file.name, 'w') as f:
+                        f.write(new_passphrase)
+
+                    image_utils.convert_image(
+                        path_to_snap_img,
+                        path_to_new_vol,
+                        'luks',
+                        passphrase_file=new_pass_file.name,
+                        src_passphrase_file=src_pass_file.name,
+                        run_as_root=self._execute_as_root)
+        else:
+            image_utils.convert_image(path_to_snap_img,
+                                      path_to_new_vol,
+                                      out_format,
+                                      run_as_root=self._execute_as_root)
 
         self._set_rw_permissions_for_all(path_to_new_vol)
