@@ -17,7 +17,6 @@
 import binascii
 import collections
 import errno
-import hashlib
 import inspect
 import json
 import math
@@ -32,6 +31,7 @@ from castellan import key_manager
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
+from oslo_utils.secretutils import md5
 from oslo_utils import units
 import six
 
@@ -172,6 +172,7 @@ class RemoteFSDriver(driver.BaseVD):
         self._execute_as_root = True
         self._is_voldb_empty_at_startup = kwargs.pop('is_vol_db_empty', None)
         self._supports_encryption = False
+        self.format = 'raw'
 
         if self.configuration:
             self.configuration.append_config_values(nas_opts)
@@ -181,7 +182,7 @@ class RemoteFSDriver(driver.BaseVD):
         """Just to override parent behavior."""
         pass
 
-    @utils.trace
+    @volume_utils.trace
     def initialize_connection(self, volume, connector):
         """Allow connection to connector and return connection info.
 
@@ -268,7 +269,7 @@ class RemoteFSDriver(driver.BaseVD):
                      acceptable_states=acceptable_states,
                      current_state=current_state))
 
-    @utils.trace
+    @volume_utils.trace
     def create_volume(self, volume):
         """Creates a volume.
 
@@ -316,6 +317,7 @@ class RemoteFSDriver(driver.BaseVD):
             # QCOW2 volumes are inherently sparse, so this setting
             # will override the _sparsed_volumes setting.
             self._create_qcow2_file(volume_path, volume_size)
+            self.format = 'qcow2'
         elif getattr(self.configuration,
                      self.driver_prefix + '_sparsed_volumes', False):
             self._create_sparsed_file(volume_path, volume_size)
@@ -323,6 +325,13 @@ class RemoteFSDriver(driver.BaseVD):
             self._create_regular_file(volume_path, volume_size)
 
         self._set_rw_permissions(volume_path)
+        if not volume.consistencygroup_id and not volume.group_id:
+            volume.admin_metadata['format'] = self.format
+            # This is done here because when creating a volume from image,
+            # while encountering other volume.save() method fails for
+            # non-admins
+            with volume.obj_as_admin():
+                volume.save()
 
     def _ensure_shares_mounted(self):
         """Look for remote shares in the flags and mount them locally."""
@@ -343,7 +352,7 @@ class RemoteFSDriver(driver.BaseVD):
 
         LOG.debug('Available shares %s', self._mounted_shares)
 
-    @utils.trace
+    @volume_utils.trace
     def delete_volume(self, volume):
         """Deletes a logical volume.
 
@@ -990,7 +999,7 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
         """
         if isinstance(base_str, six.text_type):
             base_str = base_str.encode('utf-8')
-        return hashlib.md5(base_str).hexdigest()
+        return md5(base_str, usedforsecurity=False).hexdigest()
 
     def _get_mount_point_for_share(self, share):
         """Return mount point for share.
@@ -1169,6 +1178,13 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
                                     self.local_path(volume_info))
             self._extend_volume(volume_info, volume.size)
 
+        if src_vref.admin_metadata and 'format' in src_vref.admin_metadata:
+            volume.admin_metadata['format'] = (
+                src_vref.admin_metadata['format'])
+            # This is done here because when cloning from a bootable volume,
+            # while encountering other volume.save() method fails
+            with volume.obj_as_admin():
+                volume.save()
         return {'provider_location': src_vref.provider_location}
 
     def _copy_volume_image(self, src_path, dest_path):
@@ -1725,6 +1741,7 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
         # active file never changes
         info_path = self._local_path_volume_info(snapshot.volume)
         snap_info = self._read_info_file(info_path)
+        update_format = False
 
         if utils.paths_normcase_equal(info['active_file'],
                                       info['snapshot_file']):
@@ -1746,6 +1763,7 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
                            'volume_id': snapshot.volume.id}
 
             del(snap_info[snapshot.id])
+            update_format = True
         else:
             # blockCommit snapshot into base
             # info['base'] <= snapshot_file
@@ -1761,6 +1779,11 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
 
         self._nova_assisted_vol_snap_delete(context, snapshot, delete_info)
 
+        if update_format:
+            snapshot.volume.admin_metadata['format'] = 'qcow2'
+            with snapshot.volume.obj_as_admin():
+                snapshot.volume.save()
+
         # Write info file updated above
         self._write_info_file(info_path, snap_info)
 
